@@ -2,6 +2,8 @@
  *
  * Copyright (c) 2003 by Intel Corp.
  *               2006 by IBM Corp.
+ * (C) Copyright Ulrich Kleber 2011
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  This
@@ -57,19 +59,12 @@
  * 10/13/2006  pdphan     Copy from kouzmich's hpithres.c to hpionIBMblade.c
  * 			  Add functions specifically for 
  *                          an IBM blade with Baseboard Management Controller (BMC)      
+ * 20/01/2011  ulikleber  Refactoring to use glib for option parsing and
+ *                          introduce common options for all clients,
+ *                          e.g. --domain and --host
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-#include <getopt.h>
-
-#include <SaHpi.h>
-#include <oh_utils.h>
-#include <oh_config.h>
-#include <oHpi.h>
-#include <oh_clients.h>
+#include "oh_clients.h"
 
 #define OH_SVN_REV "$Revision: 6412 $"
 
@@ -137,8 +132,7 @@ Rpt_t	*Rpts;
 int	nrpts = 0;
 long int blade_slot = 0;
 
-int	fdebug = 0;
-
+static oHpiCommonOptionsT copt;
 SaHpiSessionIdT		sessionid;
 
 static void *resize_array(void *Ar, int item_size, int *last_num, int add_num)
@@ -172,10 +166,10 @@ static void print_value(SaHpiSensorReadingT *item, char *mes)
 		return;
 	switch (item->Type) {
 		case SAHPI_SENSOR_READING_TYPE_INT64:
-			printf("%lld %s\n", item->Value.SensorInt64, mes);
+			printf("%" PRId64 " %s\n", (int64_t) item->Value.SensorInt64, mes);
 			return;
 		case SAHPI_SENSOR_READING_TYPE_UINT64:
-			printf("%llu %s\n", item->Value.SensorUint64, mes);
+			printf("%" PRIu64 " %s\n", (uint64_t) item->Value.SensorUint64, mes);
 			return;
 		case SAHPI_SENSOR_READING_TYPE_FLOAT64:
 			printf("%10.3f %s\n", item->Value.SensorFloat64, mes);
@@ -223,18 +217,21 @@ static int select_ep(Rpt_t *Rpt)
 	unsigned int i;
 	oHpiHandlerIdT this_handler_id;
 	oHpiHandlerInfoT handler_info;
+        GHashTable *config = g_hash_table_new_full(
+                                     g_str_hash, g_str_equal,
+                                     g_free, g_free );
 
 	rv = oHpiHandlerFind(sessionid,
 			     Rpt->Rpt.ResourceId,
 			     &this_handler_id);
 	if (rv) {
-		if (fdebug) printf("oHpiHandlerFind returns %s\n", oh_lookup_error(rv)); 
+		if (copt.debug) DBG("oHpiHandlerFind returns %s", oh_lookup_error(rv)); 
 		return(0);
 	}
 	
-	rv = oHpiHandlerInfo(this_handler_id, &handler_info);
+	rv = oHpiHandlerInfo(sessionid, this_handler_id, &handler_info, config);
 	if (rv) {
-		if (fdebug) printf("oHpiHandlerInfo returns %s\n", oh_lookup_error(rv));
+		if (copt.debug) DBG("oHpiHandlerInfo returns %s", oh_lookup_error(rv));
 		return(0);
 	}
 	
@@ -359,7 +356,7 @@ static void show_reading_value(Rpt_t *Rpt, Rdr_t *R)
 		R->Rdr.RdrTypeUnion.SensorRec.Num, &(R->reading), NULL);
 
 	if (rv != SA_OK) {
-		printf("ERROR: %s\n", oh_lookup_error(rv));
+		CRIT("ERROR: saHpiSensorReadingGet returns %s", oh_lookup_error(rv));
 		return;
 	};
 	k = R->Rdr.RdrTypeUnion.SensorRec.DataFormat.BaseUnits;
@@ -376,7 +373,7 @@ static void show_thresholds(Rpt_t *Rpt, Rdr_t *R)
 	rv = saHpiSensorThresholdsGet(sessionid, Rpt->Rpt.ResourceId,
 		R->Rdr.RdrTypeUnion.SensorRec.Num, &buf);
 	if (rv != SA_OK) {
-		printf("ERROR: %s\n", oh_lookup_error(rv));
+		CRIT("ERROR: saHpiSensorThresholdsGet returns %s\n", oh_lookup_error(rv));
 		return;
 	};
 	printf("  Thresholds:\n");
@@ -441,11 +438,12 @@ static void show_sens(char *S)
 static int get_number(char *mes, int *res)
 {
 	char	buf[READ_BUF_SIZE];
-	char    *ret;
+	char    *ret ;
 
 	printf("%s", mes);
 	ret = fgets(buf, READ_BUF_SIZE, stdin);
-	return (sscanf(buf, "%d", res));
+	if (ret) return (sscanf(buf, "%d", res));
+        else return -1;
 }
 
 static void set_thres_value(SaHpiSensorReadingT *R, double val)
@@ -574,7 +572,7 @@ static void mod_sen(void)
 	rv = saHpiSensorThresholdsSet(sessionid, Rpt->Rpt.ResourceId,
 		Rdr->Rdr.RdrTypeUnion.SensorRec.Num, &thres);
 	if (rv != SA_OK) {
-		printf("ERROR: saHpiSensorThresholdsSet: %s\n", oh_lookup_error(rv));
+		CRIT("ERROR: saHpiSensorThresholdsSet: %s", oh_lookup_error(rv));
 		return;
 	};
 	Rdr->modify = 1;
@@ -583,8 +581,8 @@ static void mod_sen(void)
 			NULL, NULL, NULL);
 		if (rv == SA_OK)
 			break;
-		if (fdebug) printf("sleep before saHpiEventGet\n");
-		sleep(1);
+		if (copt.debug) DBG("sleep before saHpiEventGet\n");
+		g_usleep(G_USEC_PER_SEC);
 	};
 	saHpiSensorThresholdsGet(sessionid, Rpt->Rpt.ResourceId,
 		Rdr->Rdr.RdrTypeUnion.SensorRec.Num, &thres);
@@ -893,44 +891,50 @@ static SaErrorT hpiIBMspecial_find_blade_slot(void)
 								
 int main(int argc, char **argv)
 {
-	int		c, i;
+	int		i;
 	SaErrorT	rv;
 	char		buf[READ_BUF_SIZE];
 	char		*S;
+        GOptionContext  *context;
 
-	oh_prog_version(argv[0], OH_SVN_REV);
-	while ( (c = getopt( argc, argv,"x?")) != EOF )
-		switch(c)  {
-			case 'x':
-				fdebug = 1;
-				break;
-			default:
-				printf("Usage: %s [-x]\n", argv[0]);
-				printf("   -x  Display debug messages\n");
-				return(1);
-		}
+        /* Print version strings */
+	oh_prog_version(argv[0]);
 
+        /* Parsing options */
+        static char usetext[]="- Shows how to use two (2) openhpi\n  "
+                      "plugins to display and manage resources of an IBM Blade\n  "
+                      "with Basedboard Management Controller (BMC)\n  "
+                      OH_SVN_REV; 
+        OHC_PREPARE_REVISION(usetext);
+        context = g_option_context_new (usetext);
+
+        if (!ohc_option_parse(&argc, argv, 
+                context, &copt, 
+                OHC_ALL_OPTIONS 
+                    - OHC_ENTITY_PATH_OPTION // not implemented
+                    - OHC_VERBOSE_OPTION )) {    // no verbose mode implemented
+                g_option_context_free (context);
+		return 1;
+	}
+        g_option_context_free (context);
+ 
 	rv = hpiIBMspecial_find_blade_slot();
 	if (rv != SA_OK) {
-		printf("ipmitool can not find slot number in which this blade resides.\n");
+		CRIT("ipmitool can not find slot number in which this blade resides.");
 		return(-1);
 	}
 
-	rv = saHpiSessionOpen(SAHPI_UNSPECIFIED_DOMAIN_ID, &sessionid, NULL);
+        rv = ohc_session_open_by_option ( &copt, &sessionid);
+	if (rv != SA_OK) return rv;
 
-	if (rv != SA_OK) {
-		printf("saHpiSessionOpen: %s\n", oh_lookup_error(rv));
-		return(-1);
-	}
- 
 	rv = saHpiDiscover(sessionid);
 
-	if (fdebug) printf("saHpiDiscover: %s\n", oh_lookup_error(rv));
+	if (copt.debug) DBG("saHpiDiscover: %s", oh_lookup_error(rv));
 
 	rv = saHpiSubscribe(sessionid);
 	if (rv != SA_OK) {
-		printf( "saHpiSubscribe error %d\n",rv);
-		return(-1);
+		CRIT( "saHpiSubscribe error %d",rv);
+		return rv;
 	}	
 	
 	/* make the RPT list */
@@ -949,4 +953,4 @@ int main(int argc, char **argv)
 	rv = saHpiSessionClose(sessionid);
 	return(0);
 }
- /* end hpthres.c */
+ /* end hpionIBMblade.c */
