@@ -2,6 +2,8 @@
  *
  * Copyright (c) 2003 by Intel Corp.
  * (C) Copyright IBM Corp. 2004
+ * (C) Copyright Nokia Siemens Networks 2010
+ * (C) Copyright Ulrich Kleber 2011
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,25 +15,23 @@
  * Authors:
  *     Peter D. Phan <pdphan@users.sourceforge.net>
  *     Tariq Shureih <tariq.shureih@intel.com>
+ *     Ulrich Kleber <ulikleber@users.sourceforge.net>
  *
  * Log: 
  *     Copied from hpifru.c and modified for general use
  *
  * Changes:
  *     11/03/2004  kouzmich   Fixed Bug #1057934
+ *     09/02/2010  lwetzel    Fixed Bug ResourceId 255 (0xFF) is a valid ResourceId 
+ *     07/06/2010  ulikleber  New option -D to select domain
+ *     20/01/2011  ulikleber  Refactoring to use glib for option parsing and
+ *                            introduce common options for all clients
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-#include <getopt.h>
-#include <SaHpi.h> 
-#include <oh_utils.h>
-#include <oh_clients.h>
+#include "oh_clients.h"
 
-#define OH_SVN_REV "$Revision: 6571 $"
+#define OH_SVN_REV "$Revision: 7291 $"
 
 /* 
  * Function prototypes
@@ -82,21 +82,47 @@ void sensor_readingthreshold(SaHpiSessionIdT sessionid,
 			SaHpiResourceIdT resourceid,
 			SaHpiRdrT *rdrptr);
 
-#define all_resources 255
 
 /* 
  * Globals for this driver
  */
-int fdebug = 0;
-int f_listall = 0;
-int f_rpt     = 0;
-int f_sensor  = 0;
-int f_inv     = 0;
-int f_ctrl    = 0;
-int f_rdr     = 0;
-int f_wdog    = 0;
-int f_ann     = 0;
-int f_overview = 0;
+static gboolean f_listall  = FALSE;
+static gboolean f_rpt      = FALSE;
+static gboolean f_rdr      = FALSE;
+static gboolean f_inv      = FALSE;
+static gboolean f_sensor   = FALSE;
+static gboolean f_wdog     = FALSE;
+//static gboolean f_dimi     = FALSE;   why is this implemented only in hpitop?
+//static gboolean f_fumi     = FALSE;   why is this implemented only in hpitop?
+static gboolean f_ann      = FALSE;
+static gboolean f_ctrl     = FALSE;
+static gboolean f_overview = FALSE;
+static gboolean f_allres   = TRUE;
+static gint f_resourceid = 0;   
+static oHpiCommonOptionsT copt;
+
+static GOptionEntry my_options[] =
+{
+  { "all",          'a', 0, G_OPTION_ARG_NONE, &f_listall,  "Display all rpts and rdrs (default)",       NULL },
+  { "controls",     'c', 0, G_OPTION_ARG_NONE, &f_ctrl,     "Display only controls",                     NULL },
+  { "rdrs",         'd', 0, G_OPTION_ARG_NONE, &f_rdr,      "Display rdr records",                       NULL },
+  { "inventories",  'i', 0, G_OPTION_ARG_NONE, &f_inv,      "Display only inventories",                  NULL },
+  { "rpts",         'r', 0, G_OPTION_ARG_NONE, &f_rpt,      "Display only rpts",                         NULL },
+  { "sensors",      's', 0, G_OPTION_ARG_NONE, &f_sensor,   "Display only sensors",                      NULL },
+  { "watchdogs",    'w', 0, G_OPTION_ARG_NONE, &f_wdog,     "Display only watchdogs",                    NULL },
+  { "overview",     'o', 0, G_OPTION_ARG_NONE, &f_overview, "Display system overview: rpt & rdr headers",NULL },
+
+//  { "fumis",        'f', 0, G_OPTION_ARG_NONE, &f_fumi,     "Display only fumis",                        NULL },
+//  { "dimis",        'd', 0, G_OPTION_ARG_NONE, &f_dimi,     "Display only dimis",                        NULL },
+//  { "annunciators", 'a', 0, G_OPTION_ARG_NONE, &f_ann,      "Display only annunciators",                 NULL },
+  // Annunciators not implemented
+
+  { "resource",     'n', 0, G_OPTION_ARG_INT,  &f_resourceid, "Select particular resource id to display\n\t\t\t"
+                                                            "(Used with [-cdirs] options)",              "nn" },
+  { NULL }
+};
+
+
 /* 
  * Main                
  */
@@ -104,76 +130,52 @@ int
 main(int argc, char **argv)
 {
 	SaErrorT 	rv = SA_OK;
-	
 	SaHpiSessionIdT sessionid;
-	SaHpiResourceIdT resourceid = all_resources;
-
-	int c;
+        GOptionContext *context;
 	    
-	oh_prog_version(argv[0], OH_SVN_REV);
-	while ( (c = getopt( argc, argv,"adrsoiwcn:x?")) != EOF ) {
-		switch(c) {
-			case 'a': f_listall = 1; break;
-			case 'c': f_ctrl    = 1; break;
-			case 'd': f_rdr     = 1; break;
-			case 'i': f_inv     = 1; break;
-			case 'r': f_rpt     = 1; break;
-			case 's': f_sensor  = 1; break; 
-			case 'w': f_wdog    = 1; break;
-			case 'o': f_overview = 1; break; 			 
-			case 'n':
-				if (optarg)
-					resourceid = atoi(optarg);
-				else 
-					resourceid = all_resources;
-				break;
-			case 'x': fdebug = 1; break;
-			default:
-				printf("\n\tUsage: %s [-option]\n\n", argv[0]);
-				printf("\t      (No Option) Display all rpts and rdrs\n");
-				printf("\t           -a     Display all rpts and rdrs\n");
-				printf("\t           -c     Display only controls\n");
-				printf("\t           -d     Display rdr records\n");
-				printf("\t           -i     Display only inventories\n");
-				printf("\t           -o     Display system overview: rpt & rdr headers\n");				
-				printf("\t           -r     Display only rpts\n");
-				printf("\t           -s     Display only sensors\n");
-				printf("\t           -w     Display only watchdog\n");				
-				printf("\t           -n     Select particular resource id to display\n");
-				printf("\t                  (Used with [-cdirs] options)\n");
-				printf("\t           -x     Display debug messages\n");
-				printf("\n\n\n\n");
-				exit(1);
-		}
-	}
- 
-	if (argc == 1) f_listall = 1;
+        /* Print version strings */
+        oh_prog_version(argv[0]);
 
-	if (fdebug) printf("saHpiSessionOpen\n");
-        rv = saHpiSessionOpen(SAHPI_UNSPECIFIED_DOMAIN_ID,&sessionid,NULL);
-	if (rv != SA_OK) {
-		printf("saHpiSessionOpen returns %s\n",oh_lookup_error(rv));
-		exit(-1);
+        /* Parsing options */
+        static char usetext[]="- Display system topology\n  "
+                              OH_SVN_REV; 
+        OHC_PREPARE_REVISION(usetext);
+        context = g_option_context_new (usetext);
+        g_option_context_add_main_entries (context, my_options, NULL);
+
+        if (!ohc_option_parse(&argc, argv, 
+                context, &copt, 
+                OHC_ALL_OPTIONS 
+                    - OHC_ENTITY_PATH_OPTION  //TODO: Feature 880127?
+                    - OHC_VERBOSE_OPTION )) { // no verbose mode implemented
+                g_option_context_free (context);
+		return 1;
 	}
-	if (fdebug)
-	       	printf("saHpiSessionOpen returns with SessionId %d\n", sessionid);
+        g_option_context_free (context);
+ 
+	if (f_rpt || f_sensor || f_inv || f_ctrl || f_rdr || f_wdog) 
+           f_listall = TRUE;
+	if (f_resourceid != 0) f_allres = FALSE;
+
+        rv = ohc_session_open_by_option ( &copt, &sessionid);
+	if (rv != SA_OK) return rv;
 
 	/*
 	 * Resource discovery
 	 */
-	if (fdebug) printf("saHpiDiscover\n");
+	if (copt.debug) DBG("saHpiDiscover");
 	rv = saHpiDiscover(sessionid);
 	if (rv != SA_OK) {
-		printf("saHpiDiscover returns %s\n",oh_lookup_error(rv));
-		exit(-1);
+		CRIT("saHpiDiscover returns %s",oh_lookup_error(rv));
+		return rv;
 	}
 
 	printf("Discovery done\n");
-	list_resources(sessionid, resourceid);
+	list_resources(sessionid, (SaHpiResourceIdT) f_resourceid);
 
 	rv = saHpiSessionClose(sessionid);
 	
-	exit(0);
+	return 0;
 }
 
 
@@ -196,35 +198,35 @@ SaErrorT list_resources(SaHpiSessionIdT sessionid,SaHpiResourceIdT resourceid)
 	SaHpiResourceIdT l_resourceid;
 	SaHpiTextBufferT working;
 		
-	oh_init_textbuffer(&working);																		
+        oh_init_textbuffer(&working);
 																
 	/* walk the RPT list */
 	rptentryid = SAHPI_FIRST_ENTRY;
 	do {
 		
-		if (fdebug) printf("saHpiRptEntryGet\n");
+		if (copt.debug) DBG("saHpiRptEntryGet");
 		rvRptGet = saHpiRptEntryGet(sessionid,rptentryid,&nextrptentryid,&rptentry);
-		if ((rvRptGet != SA_OK) || fdebug) 
-		       	printf("RptEntryGet returns %s\n",oh_lookup_error(rvRptGet));
+		if ((rvRptGet != SA_OK) || copt.debug) 
+		       	DBG("RptEntryGet returns %s",oh_lookup_error(rvRptGet));
 		
 		rv = list_rpt(&rptentry, resourceid);
 						
 		if (rvRptGet == SA_OK 
                    	&& (rptentry.ResourceCapabilities & SAHPI_CAPABILITY_RDR) 
-			&& ((resourceid == 0xFF) || (resourceid == rptentry.ResourceId)))
+			&& ((f_allres) || (resourceid == rptentry.ResourceId)))
 		{
 			l_resourceid = rptentry.ResourceId;
-			if (resourceid != 0xFF) 
+			if (!f_allres) 
 				 nextrptentryid = SAHPI_LAST_ENTRY;
 
 			/* walk the RDR list for this RPT entry */
 			entryid = SAHPI_FIRST_ENTRY;			
 
-			if (fdebug) printf("rptentry[%d] resourceid=%d\n", entryid,resourceid);
+			if (copt.debug) DBG("rptentry[%u] resourceid=%u\n", entryid,resourceid);
 
 			do {
 				rvRdrGet = saHpiRdrGet(sessionid,l_resourceid, entryid,&nextentryid, &rdr);
-				if (fdebug) printf("saHpiRdrGet[%d] rv = %s\n",entryid,oh_lookup_error(rvRdrGet));
+				if (copt.debug) DBG("saHpiRdrGet[%u] rv = %s\n",entryid,oh_lookup_error(rvRdrGet));
 
 
 				if (rvRdrGet == SA_OK)
@@ -260,12 +262,12 @@ SaErrorT list_rpt(SaHpiRptEntryT *rptptr,SaHpiResourceIdT resourceid)
 {
 	SaErrorT rv = SA_OK;
 
-	if ((resourceid == all_resources) ||
+	if ((f_allres) ||
 		(resourceid == rptptr->ResourceId)) {
 
 		/* Always print resource header */
 		if (!f_listall && !f_rpt) 
-		printf("\nRPT Tag: %s, ResourceId %d\n",rptptr->ResourceTag.Data, rptptr->ResourceId);
+		printf("\nRPT Tag: %s, ResourceId %u\n",rptptr->ResourceTag.Data, rptptr->ResourceId);
 		oh_print_ep(&rptptr->ResourceEntity, 0);
 		printf("\n");
 
@@ -302,7 +304,7 @@ SaErrorT list_inv(SaHpiSessionIdT sessionid,
 					&idrInfo);		
 
 		if (rvInvent !=SA_OK) {
-			printf("saHpiIdrInfoGet: ResourceId %d IdrId %d, error %s\n",
+			printf("saHpiIdrInfoGet: ResourceId %u IdrId %u, error %s\n",
 					l_resourceid, idrid, oh_lookup_error(rvInvent));
 		} else {
 			oh_print_idrinfo(&idrInfo, 4);
@@ -378,12 +380,12 @@ SaErrorT walkInventory(	SaHpiSessionIdT sessionid,
 					oh_print_idrfield(&thisField, 12);
 				}
  
-				if (fdebug) printf("saHpiIdrFieldGet  error %s\n",oh_lookup_error(rvField));
+				if (copt.debug) DBG("saHpiIdrFieldGet  error %s",oh_lookup_error(rvField));
 				fieldId = nextFieldId;
 			} while ((rvField == SA_OK) && (fieldId != SAHPI_LAST_ENTRY));
 		
 			if ( countFields != areaHeader.NumFields) 
-				printf("Area Header error! areaHeader.NumFields %d, countFields %d\n",
+				printf("Area Header error! areaHeader.NumFields %u, countFields %u\n",
 					areaHeader.NumFields, countFields);
 		} else {
 			printf("saHpiIdrAreaHeaderGet error %s\n",oh_lookup_error(rv));
@@ -393,7 +395,7 @@ SaErrorT walkInventory(	SaHpiSessionIdT sessionid,
 	} while ((rv == SA_OK) && (areaId != SAHPI_LAST_ENTRY)); 
 
 	if ((rv == SA_OK) && (countAreas != numAreas)) 
-		printf("idrInfo error! idrInfo.NumAreas = %d; countAreas = %d\n", 
+		printf("idrInfo error! idrInfo.NumAreas = %u; countAreas = %u\n", 
 				numAreas, countAreas);
  	
 	return(rv);
@@ -464,20 +466,20 @@ void sensor_readingthreshold(SaHpiSessionIdT sessionid,
         }
         
         if((rv = oh_decode_eventstate(events, sensorrec->Category, &text)) == SA_OK) {
-                printf("\t  Sensor %d state = %s\n", sensornum, text.Data);
+                printf("\t  Sensor %u state = %s\n", sensornum, text.Data);
         } else {
-                printf("\n\t  Sensor %d state FAILED, %s\n", sensornum, oh_lookup_error(rv));
+                printf("\n\t  Sensor %u state FAILED, %s\n", sensornum, oh_lookup_error(rv));
         }
         
         if (!reading.IsSupported ) {
-                printf("\t  Reading not supported for sensor %d!\n\n", sensornum);
+                printf("\t  Reading not supported for sensor %u!\n\n", sensornum);
                 return;
         } 
         
         if((rv = oh_decode_sensorreading(reading, sensorrec->DataFormat, &text)) == SA_OK) {
-                printf("\t  Sensor %d reading = %s\n", sensornum, text.Data);
+                printf("\t  Sensor %u reading = %s\n", sensornum, text.Data);
         } else {
-                printf("\n\t  Sensor %d reading FAILED, %s\n", sensornum, oh_lookup_error(rv));
+                printf("\n\t  Sensor %u reading FAILED, %s\n", sensornum, oh_lookup_error(rv));
         }
 	
 	rv = saHpiSensorThresholdsGet(sessionid,resourceid, sensornum, &thresh);
@@ -584,7 +586,7 @@ SaErrorT list_rdr(SaHpiSessionIdT sessionid,
 		rv = oh_print_rdr(rdrptr, 4);
 	} else {
 		snprintf((char *)working.Data, SAHPI_MAX_TEXT_BUFFER_LENGTH,
-			"    Found %s, RecordId %d",
+			"    Found %s, RecordId %u",
 			oh_lookup_rdrtype(rdrptr->RdrType), rdrptr->RecordId);
 		rv = oh_print_text(&working);
 	}
