@@ -1,6 +1,8 @@
 /*      -*- linux-c -*-
  *
  * Copyright (c) 2004 by Intel Corp.
+ * (C) Copyright Nokia Siemens Networks 2010
+ * (C) Copyright Ulrich Kleber 2011
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -11,11 +13,16 @@
  *
  * Filename: hpiwdt.c
  * Authors:  Andy Cress <arcress@users.sourceforge.net>
+ *      Ulrich Kleber <ulikleber@users.sourceforge.net>
  * 
  * Changes:
  * 03/15/04 Andy Cress - v1.0 added strings for use & actions in show_wdt
  * 10/13/04  kouzmich  - porting to HPI B
  * 12/02/04 Andy Cress - v1.1 fixed domain/RPT loop, added some decoding
+ * 09/06/2010 ulikleber New option -D to select domain
+ * 01/02/2011 ulikleber Refactoring to use glib for option parsing and
+ *                      introduce common options for all clients
+ *
  */
 /* 
  * This tool reads and enables the watchdog timer via HPI.
@@ -27,15 +34,10 @@
  * will reset your system.
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <getopt.h>
-#include <SaHpi.h>
-#include <oh_clients.h>
+#include "oh_clients.h"
 
 #define  uchar  unsigned char
-#define OH_SVN_REV "$Revision: 6571 $"
+#define OH_SVN_REV "$Revision: 7291 $"
 
 #define NUSE  6
 char *usedesc[NUSE] = {"reserved", "BIOS FRB2", "BIOS/POST",
@@ -43,7 +45,21 @@ char *usedesc[NUSE] = {"reserved", "BIOS FRB2", "BIOS/POST",
 #define NACT  5
 char *actions[NACT] = {"No action", "Hard Reset", "Power down",
 		    "Power cycle", "Reserved" };
-char fdebug = 0;
+
+static gboolean fenable    = FALSE;
+static gboolean fdisable = FALSE;
+static gboolean freset     = FALSE;
+static gint     ftimeout   = 0;
+static oHpiCommonOptionsT copt;
+
+static GOptionEntry my_options[] =
+{
+  { "enable",  'e', 0, G_OPTION_ARG_NONE, &fenable,  "enables the watchdog timer",  NULL },
+  { "disable", 'd', 0, G_OPTION_ARG_NONE, &fdisable, "disables the watchdog timer", NULL },
+  { "reset",   'r', 0, G_OPTION_ARG_NONE, &freset,   "resets the watchdog timer",   NULL },
+  { "timeout", 't', 0, G_OPTION_ARG_INT,  &ftimeout, "sets timeout to n seconds",   "n" },
+  { NULL }
+};
 
 static void
 show_wdt(SaHpiWatchdogNumT  wdnum, SaHpiWatchdogT *wdt)
@@ -56,11 +72,11 @@ show_wdt(SaHpiWatchdogNumT  wdnum, SaHpiWatchdogT *wdt)
   icount = wdt->InitialCount /1000;        /*1000 msec = 1 sec*/
   pcount = wdt->PresentCount /1000;
 
-  if (wdt->TimerUse > NUSE) sprintf(ustr,"%d", wdt->TimerUse );
+  if (wdt->TimerUse > NUSE) sprintf(ustr,"%u", wdt->TimerUse );
   else strcpy(ustr, usedesc[wdt->TimerUse]);
-  if (wdt->TimerAction > NACT) sprintf(astr,"%d", wdt->TimerAction );
+  if (wdt->TimerAction > NACT) sprintf(astr,"%u", wdt->TimerAction );
   else strcpy(astr, actions[wdt->TimerAction]);
-  printf("Watchdog: Num=%d, Log=%d, Running=%d, TimerUse=%s, TimerAction=%s\n",
+  printf("Watchdog: Num=%u, Log=%d, Running=%d, TimerUse=%s, TimerAction=%s\n",
 	wdnum,wdt->Log,wdt->Running,ustr, astr);
   if (wdt->TimerUseExpFlags == 0) strcpy(estr,"none");
   else {
@@ -71,7 +87,7 @@ show_wdt(SaHpiWatchdogNumT  wdnum, SaHpiWatchdogT *wdt)
 	if (wdt->TimerUseExpFlags & 0x08) strcat(estr,"SMS_OS ");
 	if (wdt->TimerUseExpFlags & 0x10) strcat(estr,"OEM ");
   }
-  printf("          ExpiredUse=%s, Timeout=%d sec, Counter=%d sec\n",
+  printf("          ExpiredUse=%s, Timeout=%u sec, Counter=%u sec\n",
 	estr, icount,pcount);
   switch(wdt->PretimerInterrupt) {
   case 1:  pstr = "SMI";    break;
@@ -79,7 +95,7 @@ show_wdt(SaHpiWatchdogNumT  wdnum, SaHpiWatchdogT *wdt)
   case 3:  pstr = "MsgInt"; break;
   default: pstr = "none";   break;
   }
-  printf("          PreTimerInterrupt=%s, PreTimeoutInterval=%d msec\n",
+  printf("          PreTimerInterrupt=%s, PreTimeoutInterval=%u msec\n",
 	 pstr,wdt->PreTimeoutInterval);
   return;
 }
@@ -87,7 +103,6 @@ show_wdt(SaHpiWatchdogNumT  wdnum, SaHpiWatchdogT *wdt)
 int
 main(int argc, char **argv)
 {
-  int c;
   SaErrorT rv;
   SaHpiSessionIdT sessionid;
   SaHpiDomainInfoT domainInfo;
@@ -97,48 +112,37 @@ main(int argc, char **argv)
   SaHpiResourceIdT resourceid;
   SaHpiWatchdogNumT  wdnum;
   SaHpiWatchdogT     wdt;
-  int t = 0;
-  char freset = 0;
-  char fenable = 0;
-  char fdisable = 0;
+  GOptionContext *context;
 
-  oh_prog_version(argv[0], OH_SVN_REV);
-  while ( (c = getopt( argc, argv,"dert:x?")) != EOF )
-     switch(c) {
-	case 'r':       /* reset wdt */
-		freset = 1;
-                break;
-	case 'e':       /* disable wdt */
-		fenable = 1;
-                break;
-	case 'd':       /* disable wdt */
-		fdisable = 1;
-                break;
-	case 't':       /* timeout (enable implied) */
-		t = atoi(optarg);
-		fenable = 1;
-                break;
-	case 'x': fdebug = 1;     break;  /* debug messages */
-	default:
-                printf("Usage: %s [-derx -t sec]\n", argv[0]);
-                printf(" where -e     enables the watchdog timer\n");
-                printf("       -d     disables the watchdog timer\n");
-                printf("       -r     resets the watchdog timer\n");
-                printf("       -t N   sets timeout to N seconds\n");
-                printf("       -x     show eXtra debug messages\n");
-		exit(1);
-     }
-  if (t == 0) t = 120;
+  /* Print version strings */
+  oh_prog_version(argv[0]);
+
+  /* Parsing options */
+  static char usetext[]="- Read and Enables the watchdog timer.\n  "
+                        OH_SVN_REV; 
+  OHC_PREPARE_REVISION(usetext);
+  context = g_option_context_new (usetext);
+  g_option_context_add_main_entries (context, my_options, NULL);
+
+  if (!ohc_option_parse(&argc, argv, 
+                context, &copt, 
+                OHC_ALL_OPTIONS 
+                    - OHC_ENTITY_PATH_OPTION  //TODO: Feature 880127
+                    - OHC_VERBOSE_OPTION )) { // no verbose mode implemented
+                g_option_context_free (context);
+		return 1;
+  }
+  g_option_context_free (context);
+  if (ftimeout == 0) ftimeout = 120;
+  else fenable = TRUE;
+  
+  rv = ohc_session_open_by_option ( &copt, &sessionid);
+  if (rv != SA_OK) return rv;
 
-  rv = saHpiSessionOpen(SAHPI_UNSPECIFIED_DOMAIN_ID, &sessionid, NULL);
-  if (rv != SA_OK) {
-        printf("saHpiSessionOpen error %d\n",rv);
-	exit(-1);
-	}
   rv = saHpiDiscover(sessionid);
-  if (fdebug) printf("saHpiDiscover rv = %d\n",rv);
+  if (copt.debug) DBG("saHpiDiscover rv = %s",oh_lookup_error(rv));
   rv = saHpiDomainInfoGet(sessionid, &domainInfo);
-  if (fdebug) printf("saHpiDomainInfoGet rv = %d\n",rv);
+  if (copt.debug) DBG("saHpiDomainInfoGet rv = %s",oh_lookup_error(rv));
   printf("DomainInfo: UpdateCount = %x, UpdateTime = %lx\n",
        domainInfo.RptUpdateCount, (unsigned long)domainInfo.RptUpdateTimestamp);
 
@@ -147,13 +151,13 @@ main(int argc, char **argv)
   while ((rv == SA_OK) && (rptentryid != SAHPI_LAST_ENTRY))
   {
      rv = saHpiRptEntryGet(sessionid,rptentryid,&nextrptentryid,&rptentry);
-     if (rv != SA_OK) printf("RptEntryGet: rv = %d\n",rv);
+     if (rv != SA_OK) printf("RptEntryGet: rv = %s\n",oh_lookup_error(rv));
      if (rv == SA_OK) {
 	/* handle WDT for this RPT entry */
 	resourceid = rptentry.ResourceId;
-	// rptentry.ResourceTag.Data[rptentry.ResourceTag.DataLength] = 0;
-	if (fdebug)
-	   printf("rptentry[%d] resourceid=%d capab=%x tag: %s\n",
+	rptentry.ResourceTag.Data[rptentry.ResourceTag.DataLength] = 0;
+	if (copt.debug)
+	   printf("rptentry[%u] resourceid=%u capab=%x tag: %s\n",
 		rptentryid, resourceid, rptentry.ResourceCapabilities, 
 		rptentry.ResourceTag.Data);
 
@@ -162,9 +166,9 @@ main(int argc, char **argv)
 
 	   wdnum = SAHPI_DEFAULT_WATCHDOG_NUM;
 	   rv = saHpiWatchdogTimerGet(sessionid,resourceid,wdnum,&wdt);
-	   if (fdebug) printf("saHpiWatchdogTimerGet rv = %d\n",rv);
+	   if (copt.debug) DBG("saHpiWatchdogTimerGet rv = %s",oh_lookup_error(rv));
 	   if (rv != 0) {
-		printf("saHpiWatchdogTimerGet error = %d\n",rv);
+		printf("saHpiWatchdogTimerGet error = %s\n",oh_lookup_error(rv));
 		rv = 0;
 		rptentryid = nextrptentryid; 
 		continue;
@@ -183,27 +187,27 @@ main(int argc, char **argv)
 	      wdt.PresentCount = 120000; /*msec*/
 
 	      rv = saHpiWatchdogTimerSet(sessionid,resourceid,wdnum,&wdt);
-	      if (fdebug) printf("saHpiWatchdogTimerSet rv = %d\n",rv);
+	      if (copt.debug) DBG("saHpiWatchdogTimerSet rv = %s",oh_lookup_error(rv));
 	      if (rv == 0) show_wdt(wdnum,&wdt);
 	   } else if (fenable) {
 	      printf("Enabling watchdog timer ...\n");
 	      /* hard reset action, no pretimeout, clear SMS/OS when done */
-	      /* use t for timeout */
+	      /* use ftimeout for timeout */
 	      wdt.TimerUse = SAHPI_WTU_SMS_OS;    /* 1=FRB2 2=POST 3=OSLoad 4=SMS_OS 5=OEM */
 	      wdt.TimerAction = SAHPI_WAE_RESET; /* 0=none 1=reset 2=powerdown 3=powercycle */
 	      wdt.PretimerInterrupt = SAHPI_WPI_NMI; /* 0=none 1=SMI 2=NMI 3=message */
-	      wdt.PreTimeoutInterval = (t / 2) * 1000; /*msec*/
-	      wdt.InitialCount = t * 1000; /*msec*/
-	      wdt.PresentCount = t * 1000; /*msec*/
+	      wdt.PreTimeoutInterval = (ftimeout / 2) * 1000; /*msec*/
+	      wdt.InitialCount = ftimeout * 1000; /*msec*/
+	      wdt.PresentCount = ftimeout * 1000; /*msec*/
 
 	      rv = saHpiWatchdogTimerSet(sessionid,resourceid,wdnum,&wdt);
-	      if (fdebug) printf("saHpiWatchdogTimerSet rv = %d\n",rv);
+	      if (copt.debug) DBG("saHpiWatchdogTimerSet rv = %s",oh_lookup_error(rv));
 	      if (rv == 0) show_wdt(wdnum,&wdt);
 	   }
 	   if (freset && !fdisable) {
 	      printf("Resetting watchdog timer ...\n");
 	      rv = saHpiWatchdogTimerReset(sessionid,resourceid,wdnum);
-	      if (fdebug) printf("saHpiWatchdogTimerReset rv = %d\n",rv);
+	      if (copt.debug) DBG("saHpiWatchdogTimerReset rv = %s",oh_lookup_error(rv));
 	   }
 	} /*watchdog capability*/
 	rptentryid = nextrptentryid;  /* get next RPT (usu only one anyway) */
@@ -212,7 +216,7 @@ main(int argc, char **argv)
  
   rv = saHpiSessionClose(sessionid);
 
-  exit(0);
+  return 0;
 }
  
 /* end hpiwdt.c */
