@@ -27,7 +27,6 @@
 #include <ctype.h>
 #include <unistd.h>
 #include <config.h>
-#include <oh_config.h>
 #include <oHpi.h>
 #include <hpi_ui.h>
 #include "hpi_cmd.h"
@@ -219,6 +218,75 @@ static ret_code_t moreset(void)
         return HPI_SHELL_OK;
 }
 
+static ret_code_t newdomain(void)
+{
+    int i;
+    char buf[SAHPI_MAX_TEXT_BUFFER_LENGTH + 1];
+    char * p;
+
+    SaHpiUint16T port;
+    SaHpiTextBufferT host;
+    SaHpiEntityPathT entity_root;
+    SaHpiDomainIdT did;
+
+    SaErrorT rv;
+
+    i = get_string_param("Host[:Port]: ", buf, SAHPI_MAX_TEXT_BUFFER_LENGTH);
+    if (i != 0) {
+        return HPI_SHELL_PARM_ERROR;
+    }
+    if (buf[0] == ':') {
+        return HPI_SHELL_PARM_ERROR;
+    }
+
+    p = strchr(buf, ':');
+    if (p != 0) {
+        *p = '\0';
+        ++p;
+        if (isdigit(*p) == 0) {
+            return HPI_SHELL_PARM_ERROR;
+        }
+        port = (SaHpiUint16T)atoi(p);
+    } else {
+        port = OPENHPI_DEFAULT_DAEMON_PORT;
+    }
+
+    host.DataType = SAHPI_TL_TYPE_TEXT;
+    host.Language = SAHPI_LANG_ENGLISH;
+    host.DataLength = strlen(buf);
+    memcpy(&host.Data[0], &buf[0], host.DataLength );
+    host.Data[host.DataLength] = '\0';
+
+    oh_init_ep(&entity_root);
+
+    i = get_string_param("Domain Id: ", buf, SAHPI_MAX_TEXT_BUFFER_LENGTH);
+    if (i == 0) {
+        p = &buf[0];
+        if (isdigit(*p) == 0) {
+            return HPI_SHELL_PARM_ERROR;
+        }
+        did = (SaHpiDomainIdT)atoi(p);
+        rv = oHpiDomainAddById(did, &host, port, &entity_root);
+        if (rv != SA_OK) {
+            printf("oHpiDomainAddById error %s\n", oh_lookup_error(rv));
+            return HPI_SHELL_CMD_ERROR;
+        }
+    } else {
+        rv = oHpiDomainAdd(&host, port, &entity_root, &did);
+        if (rv != SA_OK) {
+            printf("oHpiDomainAdd error %s\n", oh_lookup_error(rv));
+            return HPI_SHELL_CMD_ERROR;
+        }
+    }
+
+    printf("Created new domain %u (%s:%u)\n",
+           did,
+           (const char*)(&host.Data[0]),
+           port);
+
+    return HPI_SHELL_OK;
+}
+
 static ret_code_t power(void)
 {
         SaErrorT                rv;
@@ -318,6 +386,26 @@ static ret_code_t reset(void)
         return HPI_SHELL_OK;
 }
 
+static ret_code_t remove_failed_resource(void)
+{
+        SaErrorT                rv;
+        SaHpiResourceIdT        resourceid;
+        ret_code_t              ret;
+
+        ret = ask_rpt(&resourceid);
+        if (ret != HPI_SHELL_OK) {
+            return ret;
+        }
+
+        rv = saHpiResourceFailedRemove(Domain->sessionId, resourceid);
+        if (rv != SA_OK) {
+            printf("saHpiResourceFailedRemove error %s\n", oh_lookup_error(rv));
+            return HPI_SHELL_CMD_ERROR;
+        }
+
+        return HPI_SHELL_OK;
+}
+
 static ret_code_t clear_evtlog(void)
 {
         SaHpiResourceIdT        resourceid;
@@ -472,6 +560,16 @@ static ret_code_t dat_list(void)
         return show_dat(Domain, ui_print);
 }
 
+static ret_code_t listent(void)
+{
+    SaHpiEntityPathT root;
+    root.Entry[0].EntityType = SAHPI_ENT_ROOT;
+    root.Entry[0].EntityLocation = 0;
+
+    return ( show_entity_tree(Domain, &root, 0, ui_print) == SA_OK ) ?
+           HPI_SHELL_OK : HPI_SHELL_CMD_ERROR;
+}
+
 static ret_code_t listres(void)
 {
 	term_def_t	*term;
@@ -783,21 +881,41 @@ static ret_code_t show_rdr(void)
         return HPI_SHELL_OK;
 }
 
+static ret_code_t show_rdrupdatecounter(void)
+{
+    ret_code_t       ret;
+    SaHpiResourceIdT rptid;
+    SaErrorT         rv;
+    SaHpiUint32T     cnt;
+
+    ret = ask_rpt(&rptid);
+    if (ret != HPI_SHELL_OK) return(ret);
+
+    rv = saHpiRdrUpdateCountGet(Domain->sessionId, rptid, &cnt);
+    if ( rv != SA_OK ) {
+        printf( "ERROR!!! saHpiRdrUpdateCountGet: %s\n", oh_lookup_error( rv ) );
+        return HPI_SHELL_CMD_ERROR;
+    }
+    printf( "Update counter for the resource %u data records: %u\n", rptid, cnt );
+
+    return HPI_SHELL_OK;
+}
+
 static ret_code_t show_ver(void)
 {
    SaHpiVersionT ver = saHpiVersionGet();
 
-   printf("\nPackage version: %s\n", PACKAGE_VERSION);
+   printf("\nPackage version: %s\n", VERSION);
    printf("HPI specification version: SAI_HPI-%c.%02d.%02d\n\n",
    	  ('A' + (ver >> 16) -1), (ver >> 8) & 0xFF, (ver) & 0xFF);
 
    return(HPI_SHELL_OK);
 }
 
-static ret_code_t wtd_get(void)
+static ret_code_t wdt_get(void)
 {
         SaHpiResourceIdT        rptid;
-        SaHpiWatchdogNumT       wtdnum;
+        SaHpiWatchdogNumT       wdtnum;
         SaHpiWatchdogT          watchdog;
         SaHpiWatchdogExpFlagsT  flags;
         SaErrorT                rv;
@@ -807,20 +925,20 @@ static ret_code_t wtd_get(void)
 
         ret = ask_rpt(&rptid);
         if (ret != HPI_SHELL_OK) return(ret);
-        ret = ask_rdr(rptid, SAHPI_WATCHDOG_RDR, &wtdnum);
+        ret = ask_rdr(rptid, SAHPI_WATCHDOG_RDR, &wdtnum);
         if (ret != HPI_SHELL_OK) return(ret);
 
         rv = saHpiWatchdogTimerGet(Domain->sessionId,
-                rptid, wtdnum, &watchdog);
+                rptid, wdtnum, &watchdog);
         if (rv != SA_OK) {
                 printf("ERROR!!! Get Watchdog: ResourceId=%d "
                         "WatchdogNum=%d: %s\n",
-                        rptid, wtdnum, oh_lookup_error(rv));
+                        rptid, wdtnum, oh_lookup_error(rv));
                 return(HPI_SHELL_CMD_ERROR);
         };
         if (watchdog.Log) str = "TRUE";
         else str = "FALSE";
-        printf("  Watchdogtimer (%d/%d): Log=%s", rptid, wtdnum, str);
+        printf("  Watchdogtimer (%d/%d): Log=%s", rptid, wdtnum, str);
         if (watchdog.Running) str = "Running";
         else str = "Stopped";
         printf("  %s\n", str);
@@ -843,16 +961,16 @@ static ret_code_t wtd_get(void)
         };
         printf("  Timer Use: %s", str);
         switch (watchdog.TimerAction) {
-                case SAHPI_WAE_NO_ACTION:
+                case SAHPI_WA_NO_ACTION:
                         str = "NO_ACTION"; break;
-                case SAHPI_WAE_RESET:
+                case SAHPI_WA_RESET:
                         str = "RESET"; break;
-                case SAHPI_WAE_POWER_DOWN:
+                case SAHPI_WA_POWER_DOWN:
                         str = "POWER_DOWN"; break;
-                case SAHPI_WAE_POWER_CYCLE:
+                case SAHPI_WA_POWER_CYCLE:
                         str = "POWER_CYCLE"; break;
-                case SAHPI_WAE_TIMER_INT:
-                        str = "TIMER_INT"; break;
+                //case SAHPI_WAE_TIMER_INT:           
+                //        str = "TIMER_INT"; break;
                 default: str = "Unknown"; break;
         };
         printf("  Action: %s", str);
@@ -893,10 +1011,10 @@ static ret_code_t wtd_get(void)
         return HPI_SHELL_OK;
 }
 
-static ret_code_t wtd_set(void)
+static ret_code_t wdt_set(void)
 {
         SaHpiResourceIdT        rptid;
-        SaHpiWatchdogNumT       wtdnum;
+        SaHpiWatchdogNumT       wdtnum;
         SaHpiWatchdogT          watchdog;
         SaHpiWatchdogExpFlagsT  flags;
         SaErrorT                rv;
@@ -907,7 +1025,7 @@ static ret_code_t wtd_set(void)
 
         ret = ask_rpt(&rptid);
         if (ret != HPI_SHELL_OK) return(ret);
-        ret = ask_rdr(rptid, SAHPI_WATCHDOG_RDR, &wtdnum);
+        ret = ask_rdr(rptid, SAHPI_WATCHDOG_RDR, &wdtnum);
         if (ret != HPI_SHELL_OK) return(ret);
 
         i = get_string_param("Log(0 | 1): ", tmp, 255);
@@ -1032,31 +1150,31 @@ static ret_code_t wtd_set(void)
         };
         watchdog.InitialCount = res;
 
-        rv = saHpiWatchdogTimerSet(Domain->sessionId, rptid, wtdnum, &watchdog);
+        rv = saHpiWatchdogTimerSet(Domain->sessionId, rptid, wdtnum, &watchdog);
         if (rv != SA_OK) {
                 printf("ERROR!!! Set Watchdog: ResourceId=%d WatchdogNum=%d: %s\n",
-                        rptid, wtdnum, oh_lookup_error(rv));
+                        rptid, wdtnum, oh_lookup_error(rv));
                 return(HPI_SHELL_CMD_ERROR);
         };
         return HPI_SHELL_OK;
 }
 
-static ret_code_t wtd_reset(void)
+static ret_code_t wdt_reset(void)
 {
         SaHpiResourceIdT        rptid;
-        SaHpiWatchdogNumT       wtdnum;
+        SaHpiWatchdogNumT       wdtnum;
         SaErrorT                rv;
         ret_code_t              ret;
 
         ret = ask_rpt(&rptid);
         if (ret != HPI_SHELL_OK) return(ret);
-        ret = ask_rdr(rptid, SAHPI_WATCHDOG_RDR, &wtdnum);
+        ret = ask_rdr(rptid, SAHPI_WATCHDOG_RDR, &wdtnum);
         if (ret != HPI_SHELL_OK) return(ret);
 
-        rv = saHpiWatchdogTimerReset(Domain->sessionId, rptid, wtdnum);
+        rv = saHpiWatchdogTimerReset(Domain->sessionId, rptid, wdtnum);
         if (rv != SA_OK) {
                 printf("ERROR!!! Reset Watchdog: ResourceId=%d WatchdogNum=%d: %s\n",
-                        rptid, wtdnum, oh_lookup_error(rv));
+                        rptid, wdtnum, oh_lookup_error(rv));
                 return(HPI_SHELL_CMD_ERROR);
         };
         return HPI_SHELL_OK;
@@ -1097,7 +1215,7 @@ static ret_code_t reopen_session(void)
         if (rv != SA_OK) {
                 printf("saHpiSessionClose error %s\n", oh_lookup_error(rv));
         }
-        if (open_session(eflag) != 0) {
+        if (open_session(Domain->domainId, eflag) != 0) {
                 printf("Can not open session\n");
                 return(HPI_SHELL_CMD_ERROR);
         }
@@ -1145,6 +1263,77 @@ static ret_code_t echo(void)
         return(HPI_SHELL_OK);
 }
 
+static ret_code_t entity_instruments(void)
+{
+    term_def_t * term;
+    SaHpiEntityPathT ep;
+    SaHpiRdrTypeT type;
+    ret_code_t ret;
+    char buf[3];
+    char type_symbol;
+
+    ret = ask_entity(&ep);
+    if (ret != HPI_SHELL_OK) {
+        return(ret);
+    }
+
+    term = get_next_term();
+    if (term == NULL) {
+        if (read_file) return(HPI_SHELL_CMD_ERROR);
+        ret = get_string_param("Instrument Type (s|a|c|w|i|d|f) ==> ", buf, sizeof(buf));
+        if ( ( ret != 0 ) || ( buf[0] == '\0' ) || ( buf[1] != 0 ) ) {
+    		return HPI_SHELL_PARM_ERROR;
+        }
+        type_symbol = buf[0];
+    } else {
+        if ( ( term->term[0] == '\0' ) || ( term->term[1] != 0 ) ) {
+    		return HPI_SHELL_PARM_ERROR;
+        }
+        type_symbol = term->term[0];
+    };
+    switch ( type_symbol ) {
+        case 'c':
+            type = SAHPI_CTRL_RDR;
+            break;
+        case 's':
+            type = SAHPI_SENSOR_RDR;
+            break;
+        case 'i':
+            type = SAHPI_INVENTORY_RDR;
+            break;
+        case 'w':
+            type = SAHPI_WATCHDOG_RDR;
+            break;
+        case 'a':
+            type = SAHPI_ANNUNCIATOR_RDR;
+            break;
+        case 'd':
+            type = SAHPI_DIMI_RDR;
+            break;
+        case 'f':
+            type = SAHPI_FUMI_RDR;
+            break;
+        default:
+            return HPI_SHELL_PARM_ERROR;
+    }
+
+    return ( show_entity_management(Domain, &ep, type, ui_print) == SA_OK) ?
+           HPI_SHELL_OK : HPI_SHELL_CMD_ERROR;
+}
+
+static ret_code_t entity_resources(void)
+{
+    SaHpiEntityPathT ep;
+    ret_code_t ret;
+
+    ret = ask_entity(&ep);
+    if (ret != HPI_SHELL_OK) {
+        return(ret);
+    }
+    return ( show_entity_management(Domain, &ep, SAHPI_NO_RECORD, ui_print) == SA_OK) ?
+           HPI_SHELL_OK : HPI_SHELL_CMD_ERROR;
+}
+
 static ret_code_t domain_info(void)
 {
         SaHpiDomainInfoT        info;
@@ -1183,13 +1372,8 @@ static ret_code_t domain_info(void)
 
 ret_code_t domain_proc(void)
 {
-        SaHpiDomainInfoT        info;
-        SaHpiEntryIdT           entryid, nextentryid;
-        SaHpiDrtEntryT          drtentry;
-        SaErrorT                rv;
         SaHpiDomainIdT          id;
-        SaHpiSessionIdT         sessionId;
-        int                     i, n, first;
+        int                     i, n;
         gpointer                ptr;
         Domain_t                *domain = (Domain_t *)NULL;
         Domain_t                *new_domain;
@@ -1197,41 +1381,7 @@ ret_code_t domain_proc(void)
 
         term = get_next_term();
         if (term == NULL) {
-                printf("Domain list:\n");
-                printf("    ID: %d   SessionId: %d", Domain->domainId,
-                        Domain->sessionId);
-                rv = saHpiDomainInfoGet(Domain->sessionId, &info);
-                if (rv == SA_OK) {
-                        print_text_buffer_text("    Tag: ",
-                                &(info.DomainTag), NULL, ui_print);
-                };
-                printf("\n");
-                entryid = SAHPI_FIRST_ENTRY;
-                first = 1;
-                while (entryid != SAHPI_LAST_ENTRY) {
-                        rv = saHpiDrtEntryGet(Domain->sessionId, entryid,
-                                &nextentryid, &drtentry);
-                        if (rv != SA_OK) break;
-                        if (first) {
-                                first = 0;
-                                printf("        Domain Reference Table:\n");
-                        };
-                        printf("            ID: %d", drtentry.DomainId);
-                        entryid = nextentryid;
-                        rv = saHpiSessionOpen(drtentry.DomainId,
-                                                &sessionId, NULL);
-                        if (rv != SA_OK) {
-                                printf("\n");
-                                continue;
-                        };
-                        rv = saHpiDomainInfoGet(sessionId, &info);
-                        if (rv == SA_OK) {
-                                print_text_buffer_text("    Tag: ",  &(info.DomainTag), NULL, ui_print);
-                        };
-                        saHpiSessionClose(sessionId);
-                        printf("\n");
-                }
-                return(HPI_SHELL_OK);
+                return(HPI_SHELL_PARM_ERROR);
         };
 
         if (isdigit(term->term[0]))
@@ -1261,6 +1411,56 @@ ret_code_t domain_proc(void)
         add_domain(Domain);
         return(HPI_SHELL_OK);
 }
+
+
+static ret_code_t show_drt(void)
+{
+    SaErrorT rv;
+    SaHpiDomainInfoT dinfo;
+    SaHpiEntryIdT id, nextid;
+
+    rv = saHpiDomainInfoGet(Domain->sessionId, &dinfo);
+    if (rv != SA_OK) {
+        printf("ERROR!!! saHpiDomainInfoGet: %s\n", oh_lookup_error(rv));
+        return(HPI_SHELL_CMD_ERROR);
+    }
+    printf("DRT for Domain %u, Session %u,", Domain->domainId, Domain->sessionId);
+    print_text_buffer_text(" Tag: ", &(dinfo.DomainTag), NULL, ui_print);
+    printf("\n");
+
+    id = SAHPI_FIRST_ENTRY;
+    while (id != SAHPI_LAST_ENTRY) {
+        SaHpiDrtEntryT drte;
+        SaHpiSessionIdT sessionId;
+
+        rv = saHpiDrtEntryGet(Domain->sessionId, id, &nextid, &drte);
+        if (rv == SA_ERR_HPI_NOT_PRESENT) {
+            break;
+        } else if (rv != SA_OK) {
+            printf("ERROR!!! saHpiDrtEntryGet: %s\n", oh_lookup_error(rv));
+            return HPI_SHELL_CMD_ERROR;
+        }
+        printf("   Domain %u", drte.DomainId);
+        if (drte.IsPeer != SAHPI_FALSE ) {
+            printf(", Peer");
+        }
+        rv = saHpiSessionOpen(drte.DomainId, &sessionId, 0);
+        if (rv == SA_OK) {
+            rv = saHpiDomainInfoGet(sessionId, &dinfo);
+            if (rv == SA_OK) {
+                print_text_buffer_text(", Accessible, Tag: ",  &(dinfo.DomainTag), NULL, ui_print);
+            };
+            rv = saHpiSessionClose(sessionId);
+        };
+        printf( "\n" );
+
+        id = nextid;
+    }
+
+    return HPI_SHELL_OK;
+}
+
+
 #ifdef KUZ_DEBUG
 static ret_code_t test_cmd(void)
 {
@@ -1295,14 +1495,23 @@ const char dimiblockhelp[] = "dimi: DIMI command block\n"
                         "       DimiId:: <resourceId> <DimiNum>\n";
 const char debughelp[] = "debug: set or unset OPENHPI_ERROR environment\n"
                         "Usage: debug [ on | off ]";
-const char domainhelp[] = "domain: show domain list and set current domain\n"
+const char domainhelp[] = "domain: set current domain\n"
                         "Usage: domain [<domain id>]";
 const char domaininfohelp[] = "domaininfo: show current domain info\n"
                         "Usage: domaininfo";
+const char drthelp[] = "drt: show DRT for the current domain\n"
+                        "Usage: drt";
 const char dscvhelp[] = "dscv: discovery resources\n"
                         "Usage: dscv ";
 const char echohelp[] = "echo: pass string to the stdout\n"
                         "Usage: echo <string>";
+const char entinstrhelp[] = "entinstr: list instruments for an entity\n"
+                        "Usage: entinstr [<entity>] [type]\n"
+                        "       type =  c - control, s - sensor, i - inventory\n"
+                        "               w - watchdog, a - annunciatori, d - dimi,\n"
+                        "               f - fumi";
+const char entreshelp[] = "entres: list resources for an entity\n"
+                        "Usage: entres [<entity>]";
 const char eventhelp[] = "event: enable or disable event display on screen\n"
                         "Usage: event [enable|disable|short|full] ";
 const char evtlresethelp[] = "evtlogreset: reset the OverflowFlag in the event log\n"
@@ -1315,8 +1524,8 @@ const char exechelp[] = "exec: execute external program\n"
                         "Usage: exec <filename> [parameters]";
 const char fumiblockhelp[] = "fumi: FUMI command block\n"
                         "Usage: fumi [<FumiId>]\n"
-                        "       DimiId:: <resourceId> <FumiNum>\n";
-const char helphelp[] = "help: help information for OpenHPI commands\n"
+                        "       FumiId:: <resourceId> <FumiNum>\n";
+const char helphelp[] = "help: help information for hpi_shell commands\n"
                         "Usage: help [optional commands]";
 const char historyhelp[] = "history: show input commands history\n"
                         "Usage: history";
@@ -1329,12 +1538,16 @@ const char hsstathelp[] = "hotswapstat: retrieve hot swap state of a resource\n"
 const char invhelp[] =  "inv: inventory command block\n"
                         "Usage: inv [<InvId>]\n"
                         "       InvId:: <resourceId> <IdrId>\n";
+const char lenthelp[] = "lenthelp: list entities visible in the system\n"
+                        "Usage: lsent";
 const char lreshelp[] = "lsres: list resources\n"
                         "Usage: lsres [stat] [path]";
 const char lsorhelp[] = "lsensor: list sensors\n"
                         "Usage: lsensor";
 const char morehelp[] = "more: set or unset more enable\n"
                         "Usage: more [ on | off ]";
+const char newdomainhelp[] = "newdomain: create new domain\n"
+                        "Usage: newdomain <host>[:<port>] [<domain_id>]";
 const char parmctrlhelp[] = "parmctrl: save and restore parameters for a resource\n"
                         "Usage: parmctrl <resource id> <action>\n"
                         "    action - default | save | restore";
@@ -1342,8 +1555,13 @@ const char powerhelp[] = "power: power the resource on, off or cycle\n"
                         "Usage: power <resource id> [on|off|cycle]";
 const char quithelp[] = "quit: close session and quit console\n"
                         "Usage: quit";
+const char rdrupdatecounterhelp[] = "rdrupdatecounter: shows update counter for the"
+                        " resource data records\n"
+                        "Usage: rdrupdatecounter <resource id>\n";
 const char resethelp[] = "reset: perform specified reset on the entity\n"
                         "Usage: reset <resource id> [cold|warm|assert|deassert]";
+const char removefailedhelp[] = "removefailed: remove RPT entry for failed resource\n"
+                        "Usage: removefailed <resource id>";
 const char reopenhelp[] = "reopen: reopens session\n"
                         "Usage: reopen [force]\n"
                           "force flag skips old session closing check";
@@ -1365,19 +1583,20 @@ const char showinvhelp[] = "showinv: show inventory data of a resource\n"
 const char showrdrhelp[] = "showrdr: show resource data record\n"
                         "Usage: showrdr [<resource id> [type [<rdr num>]]]\n"
                         "   or  rdr [<resource id> [type [<rdr num>]]]\n"
-                        "       type =  c - control rdr, s - sensor, i - inventory rdr\n"
-                        "               w - watchdog, a - annunciator";
+                        "       type =  c - control, s - sensor, i - inventory\n"
+                        "               w - watchdog, a - annunciatori, d - dimi,\n"
+                        "               f - fumi";
 const char showrpthelp[] = "showrpt: show resource information\n"
                         "Usage: showrpt [<resource id>]\n"
                         "   or  rpt [<resource id>]";
 const char versionhelp[] = "ver: show HPI specification, package versions\n"
                         "Usage: ver";
-const char wtdgethelp[] = "wtdget: show watchdog timer\n"
-                        "Usage: wtdget <resource id> <watchdogNum>";
-const char wtdresethelp[] = "wtdreset: reset watchdog timer\n"
-                        "Usage: wtdreset <resource id>";
-const char wtdsethelp[] = "wtdset: set watchdog timer\n"
-                        "Usage: wtdset <resource id> <watchdogNum> <values>";
+const char wdtgethelp[] = "wdtget: show watchdog timer\n"
+                        "Usage: wdtget <resource id> <watchdogNum>";
+const char wdtresethelp[] = "wdtreset: reset watchdog timer\n"
+                        "Usage: wdtreset <resource id>";
+const char wdtsethelp[] = "wdtset: set watchdog timer\n"
+                        "Usage: wdtset <resource id> <watchdogNum> <values>";
 //  sensor command block
 const char sen_dishelp[] = "disable: set sensor disable\n"
                         "Usage: disable";
@@ -1463,14 +1682,20 @@ const char dimi_statushelp[] = "status: shows status of specified test\n"
 const char dimi_resultshelp[] = "results: show results from the last run of specified test\n"
                         "Usage: results <testNum>";
 //  FUMI command block
+const char fumi_specinfohelp[] = "specinfo: identifies the specification-defined framework "
+                         "underlying a FUMI implementation\n"
+                         "Usage: specinfo";
+const char fumi_serviceimpacthelp[] = "serviceimpact: shows information about the potential service "
+                        "impact of an upgrade process on a FUMI\n"
+                        "Usage: serviceimpact";
 const char fumi_setsourcehelp[] = "setsource : set new source information to the specified bank\n"
                         "Usage: setsource <bankNum> <sourceURI>";
 const char fumi_validatesourcehelp[] = "validatesource : initiates the validation of the integrity of "
                         "the source image associated with the designated bank\n"
                         "Usage: validatesource <bankNum>";
-const char fumi_getsourcehelp[] = "getsource : shows information about the source image assigned to "
+const char fumi_sourceinfohelp[] = "sourceinfo : shows information about the source image assigned to "
                         "designated bank\n"
-                        "Usage: getsource <bankNum>";
+                        "Usage: sourceinfo <bankNum>";
 const char fumi_targetinfohelp[] = "targetinfo : shows information about the specified bank\n"
                         "Usage: targetinfo <bankNum>";
 const char fumi_backuphelp[] = "backup : initiates a backup of currently active bank\n"
@@ -1484,15 +1709,24 @@ const char fumi_installhelp[] = "install : starts an installation process, loadi
                         "Usage: install <bankNum>";
 const char fumi_statushelp[] = "status : shows upgrade status of the FUMI\n"
                         "Usage: status <bankNum>";
-const char fumi_verifytargethelp[] = "verifytarget : starts the verification process of the upgraded image\n"
-                        "Usage: verifytarget <bankNum>";
+const char fumi_verifyhelp[] = "verify : starts the verification process of the upgraded image\n"
+                        "Usage: verify <bankNum>";
+const char fumi_verifymainhelp[] = "verifymain : starts the verification process of the "
+                        "main firmware instance in the logical bank\n"
+                        "Usage: verifymain";
 const char fumi_cancelhelp[] = "cancel : stops upgrade asynchronous operation in progress\n"
                         "Usage: cancel <bankNum>";
+const char fumi_disableautorollbackhelp[] = "disableautorollback: gets/sets autorollback disable option\n"
+                        "Usage: disableautorollback [ on | off ]";
 const char fumi_rollbackhelp[] = "rollback : initiates a rollback operation to "
                         "restore the currently active bank with a backup version\n"
                         "Usage: rollback ";
-const char fumi_activatehelp[] = "activate : starts execution of the active image on the FUMI\n"
-                        "Usage: activate ";
+const char fumi_activatehelp[] = "activate : initiates firmware activation in either "
+                        "the logical bank or the explicit banks on the FUMI\n"
+                        "Usage: activate [logical]";
+const char fumi_cleanuphelp[] = "cleanup: performs cleanup after an upgrade process on the "
+                        "specified bank, returning it to a predefined state\n"
+                        "Usage: cleanup <bankNum>";
 
 command_def_t commands[] = {
     { "addcfg",         add_config,     addcfghelp,     MAIN_COM },
@@ -1504,8 +1738,11 @@ command_def_t commands[] = {
     { "dimi",           dimi_block,     dimiblockhelp,  MAIN_COM },
     { "domain",         domain_proc,    domainhelp,     MAIN_COM },
     { "domaininfo",     domain_info,    domaininfohelp, MAIN_COM },
+    { "drt",            show_drt,       drthelp,        MAIN_COM },
     { "dscv",           discovery,      dscvhelp,       MAIN_COM },
     { "echo",           echo,           echohelp,       UNDEF_COM },
+    { "entinstr",       entity_instruments, entinstrhelp,   UNDEF_COM },
+    { "entres",         entity_resources, entreshelp,   UNDEF_COM },
     { "event",          event,          eventhelp,      UNDEF_COM },
     { "evtlogtime",     evtlog_time,    evtlogtimehelp, MAIN_COM },
     { "evtlogreset",    evtlog_reset,   evtlresethelp,  MAIN_COM },
@@ -1516,14 +1753,18 @@ command_def_t commands[] = {
     { "history",        history_cmd,    historyhelp,    UNDEF_COM },
     { "hs",             hs_block,       hsblockhelp,    MAIN_COM },
     { "inv",            inv_block,      invhelp,        MAIN_COM },
+    { "lsent",          listent,        lenthelp,       UNDEF_COM },
     { "lsres",          listres,        lreshelp,       UNDEF_COM },
     { "lsensor",        list_sensor,    lsorhelp,       MAIN_COM },
     { "more",           moreset,        morehelp,       UNDEF_COM },
+    { "newdomain",      newdomain,      newdomainhelp,  MAIN_COM },
     { "parmctrl",       parmctrl,       parmctrlhelp,   MAIN_COM },
     { "power",          power,          powerhelp,      MAIN_COM },
     { "quit",           quit,           quithelp,       UNDEF_COM },
     { "rdr",            show_rdr,       showrdrhelp,    MAIN_COM },
+    { "rdrupdatecounter", show_rdrupdatecounter,       rdrupdatecounterhelp,    MAIN_COM },
     { "reopen",         reopen_session, reopenhelp,     UNDEF_COM },
+    { "removefailed",   remove_failed_resource, removefailedhelp,  MAIN_COM },
     { "reset",          reset,          resethelp,      MAIN_COM },
     { "rpt",            show_rpt,       showrpthelp,    MAIN_COM },
     { "run",            run,            runhelp,        MAIN_COM },
@@ -1536,9 +1777,9 @@ command_def_t commands[] = {
     { "showrdr",        show_rdr,       showrdrhelp,    MAIN_COM },
     { "showrpt",        show_rpt,       showrpthelp,    MAIN_COM },
     { "ver",            show_ver,       versionhelp,    UNDEF_COM },
-    { "wtdget",         wtd_get,        wtdgethelp,     MAIN_COM },
-    { "wtdreset",       wtd_reset,      wtdresethelp,   MAIN_COM },
-    { "wtdset",         wtd_set,        wtdsethelp,     MAIN_COM },
+    { "wdtget",         wdt_get,        wdtgethelp,     MAIN_COM },
+    { "wdtreset",       wdt_reset,      wdtresethelp,   MAIN_COM },
+    { "wdtset",         wdt_set,        wdtsethelp,     MAIN_COM },
     { "?",              help_cmd,       helphelp,       UNDEF_COM },
 #ifdef KUZ_DEBUG
     { "test",           test_cmd,       helphelp,       UNDEF_COM },
@@ -1589,19 +1830,24 @@ command_def_t commands[] = {
     { "status",         dimi_block_status,   dimi_statushelp,   DIMI_COM },
     { "results",        dimi_block_results,  dimi_resultshelp,  DIMI_COM },
 // FUMI command block
-    { "setsource",      fumi_block_setsource,      fumi_setsourcehelp,       FUMI_COM },
-    { "validatesource", fumi_block_validatesource, fumi_validatesourcehelp,  FUMI_COM },
-    { "getsource",      fumi_block_getsource,      fumi_getsourcehelp,       FUMI_COM },
-    { "targetinfo",     fumi_block_targetinfo,     fumi_targetinfohelp,      FUMI_COM },
-    { "backup",         fumi_block_backup,         fumi_backuphelp,          FUMI_COM },
-    { "setbootorder",   fumi_block_setbootorder,   fumi_setbootorderhelp,    FUMI_COM },
-    { "bankcopy",       fumi_block_bankcopy,       fumi_bankcopyhelp,        FUMI_COM },
-    { "install",        fumi_block_install,        fumi_installhelp,         FUMI_COM },
-    { "status",         fumi_block_status,         fumi_statushelp,          FUMI_COM },
-    { "verifytarget",   fumi_block_verifytarget,   fumi_verifytargethelp,    FUMI_COM },
-    { "cancel",         fumi_block_cancel,         fumi_cancelhelp,          FUMI_COM },
-    { "rollback",       fumi_block_rollback,       fumi_rollbackhelp,        FUMI_COM },
-    { "activate",       fumi_block_activate,       fumi_activatehelp,        FUMI_COM },
+    { "specinfo",       fumi_block_specinfo,                   fumi_specinfohelp,            FUMI_COM },
+    { "serviceimpact",  fumi_block_serviceimpact,              fumi_serviceimpacthelp,       FUMI_COM },
+    { "setsource",      fumi_block_setsource,                  fumi_setsourcehelp,           FUMI_COM },
+    { "validatesource", fumi_block_validatesource,             fumi_validatesourcehelp,      FUMI_COM },
+    { "sourceinfo",     fumi_block_sourceinfo,                 fumi_sourceinfohelp,          FUMI_COM },
+    { "targetinfo",     fumi_block_targetinfo,                 fumi_targetinfohelp,          FUMI_COM },
+    { "backup",         fumi_block_backup,                     fumi_backuphelp,              FUMI_COM },
+    { "setbootorder",   fumi_block_setbootorder,               fumi_setbootorderhelp,        FUMI_COM },
+    { "bankcopy",       fumi_block_bankcopy,                   fumi_bankcopyhelp,            FUMI_COM },
+    { "install",        fumi_block_install,                    fumi_installhelp,             FUMI_COM },
+    { "status",         fumi_block_status,                     fumi_statushelp,              FUMI_COM },
+    { "verify",         fumi_block_verify,                     fumi_verifyhelp,              FUMI_COM },
+    { "verifymain",     fumi_block_verifymain,                 fumi_verifymainhelp,          FUMI_COM },
+    { "cancel",         fumi_block_cancel,                     fumi_cancelhelp,              FUMI_COM },
+    { "disableautorollback",   fumi_block_disableautorollback, fumi_disableautorollbackhelp, FUMI_COM },
+    { "rollback",       fumi_block_rollback,                   fumi_rollbackhelp,            FUMI_COM },
+    { "activate",       fumi_block_activate,                   fumi_activatehelp,            FUMI_COM },
+    { "cleanup",        fumi_block_cleanup,                    fumi_cleanuphelp,             FUMI_COM },
 // Terminator
     { NULL,             NULL,           NULL,           MAIN_COM }
 };
