@@ -21,6 +21,7 @@
 
 #define SHOW_BUF_SZ     1024
 
+#define HPIBOOL2STR( x ) ( ( x == SAHPI_TRUE ) ? "TRUE" : "FALSE" )
 
 extern char     *lookup_proc(int num, int val);
 extern SaErrorT decode_proc(int num, void *val, char *buf, int bufsize);
@@ -134,6 +135,15 @@ int show_threshold(SaHpiSessionIdT sessionid, SaHpiResourceIdT resourceid,
         };
         if (categ != SAHPI_EC_THRESHOLD)
                 return(SA_OK);
+        if (sendef->IsAccessible == SAHPI_FALSE) {
+                proc("Thresholds are not accessible.\n");
+                return(SA_OK);
+        }
+        if (sendef->ReadThold == 0) {
+                proc("Thresholds are not readable.\n");
+                return(SA_OK);
+        }
+
         memset(&senstbuff, 0, sizeof(SaHpiSensorThresholdsT));
         rv = saHpiSensorThresholdsGet(sessionid, resourceid, sensornum, &senstbuff);
         if (rv != SA_OK) {
@@ -143,10 +153,6 @@ int show_threshold(SaHpiSessionIdT sessionid, SaHpiResourceIdT resourceid,
                 proc(buf);
                 return -1;
         };
-        if (sendef->IsAccessible == 0) {
-                proc("Thresholds are not accessible.\n");
-                return -1;
-        };
         res = print_thres_value(&(senstbuff.LowMinor), "Lower Minor Threshold",
                 sendef, SAHPI_ES_LOWER_MINOR, proc);
         if (res == HPI_UI_END) return(HPI_UI_END);
@@ -189,7 +195,7 @@ SaErrorT show_control(SaHpiSessionIdT sessionid, SaHpiResourceIdT resourceid,
         SaHpiCtrlRecStreamT     *stream;
         SaHpiCtrlRecTextT       *text;
         SaHpiCtrlRecOemT        *oem;
-        int                     i;
+        int                     i, i0;
 
         rv = saHpiRdrGetByInstrumentId(sessionid, resourceid, SAHPI_CTRL_RDR,
                 num, &rdr);
@@ -210,11 +216,11 @@ SaErrorT show_control(SaHpiSessionIdT sessionid, SaHpiResourceIdT resourceid,
         if (proc(buf) != HPI_UI_OK) return(SA_OK);
         if (ctrl->DefaultMode.ReadOnly) str = "(Read Only)";
         else str = " ";
-        snprintf(buf, SHOW_BUF_SZ, "  Mode: %s  %s\n",
+        snprintf(buf, SHOW_BUF_SZ, "Default Mode: %s  %s\n",
                 oh_lookup_ctrlmode(ctrl->DefaultMode.Mode), str);
         if (proc(buf) != HPI_UI_OK) return(SA_OK);
 
-        if (proc("Data:\n") != HPI_UI_OK) return(SA_OK);
+        if (proc("Default Data:\n") != HPI_UI_OK) return(SA_OK);
         switch (type) {
                 case SAHPI_CTRL_TYPE_DIGITAL:
                         digit = &(ctrl->TypeUnion.Digital);
@@ -273,8 +279,9 @@ SaErrorT show_control(SaHpiSessionIdT sessionid, SaHpiResourceIdT resourceid,
                         if (proc(buf) != HPI_UI_OK) return(SA_OK);
                         sprintf(buf, "Default: MId = %d  Body = ", oem->MId);
                         str = (char *)(oem->Default.Body);
+                        i0 = strlen( buf );
                         for (i = 0; i < oem->Default.BodyLength; i++)
-                                sprintf(buf + i * 3, "%2.2X ", (unsigned char)(str[i]));
+                                sprintf(buf + i0 + i * 3, "%2.2X ", (unsigned char)(str[i]));
                         strcat(buf, "\n");
                         break;
                 default: strcpy(buf, "Unknown control type\n");
@@ -768,7 +775,7 @@ int show_rpt_list(Domain_t *domain, int as, SaHpiResourceIdT rptid,
                 if (cap & SAHPI_CAPABILITY_ANNUNCIATOR) strcat(buf, "AN|");
                 if (cap & SAHPI_CAPABILITY_FRU) strcat(buf, "FRU|");
                 if (cap & SAHPI_CAPABILITY_CONTROL) strcat(buf, "CNT|");
-                if (cap & SAHPI_CAPABILITY_WATCHDOG) strcat(buf, "WTD|");
+                if (cap & SAHPI_CAPABILITY_WATCHDOG) strcat(buf, "WDT|");
                 if (cap & SAHPI_CAPABILITY_MANAGED_HOTSWAP) strcat(buf, "HS|");
                 if (cap & SAHPI_CAPABILITY_CONFIGURATION) strcat(buf, "CF |");
                 if (cap & SAHPI_CAPABILITY_AGGREGATE_STATUS) strcat(buf, "AG|");
@@ -1006,12 +1013,14 @@ SaErrorT show_dat(Domain_t *domain, hpi_ui_print_cb_t proc)
         char            buf[SHOW_BUF_SZ];
         char            time[256];
         int             ind;
+        int             first = 1;
 
         alarm.AlarmId = SAHPI_FIRST_ENTRY;
         while (rv == SA_OK) {
                 rv = saHpiAlarmGetNext(domain->sessionId, SAHPI_ALL_SEVERITIES, FALSE,
                         &alarm);
                 if (rv != SA_OK) break;
+                first = 0;
                 snprintf(buf, SHOW_BUF_SZ, "(%d) ", alarm.AlarmId);
                 time2str(alarm.Timestamp, time, 256);
                 strcat(buf, time);
@@ -1034,13 +1043,163 @@ SaErrorT show_dat(Domain_t *domain, hpi_ui_print_cb_t proc)
                 if (proc(buf) != 0)
                         return(-1);
         };
-        if (rv == SA_ERR_HPI_NOT_PRESENT) {
+        if ( (rv == SA_ERR_HPI_NOT_PRESENT) && (first == 1) ) {
                 proc("No alarms in DAT.\n");
                 return(SA_OK);
         };
         return(rv);
 }
 
+SaErrorT show_entity_management( Domain_t *domain, const SaHpiEntityPathT * ep,
+                                 SaHpiRdrTypeT type, hpi_ui_print_cb_t proc )
+{
+    SaErrorT rv;
+    char buf[SHOW_BUF_SZ];
+
+    SaHpiUint32T i;
+    SaHpiResourceIdT rid;
+    SaHpiInstrumentIdT instr;
+    SaHpiUint32T update_cnt;
+    SaHpiBoolT first, found;
+
+    oh_big_textbuffer tmpbuf;
+    oh_init_bigtext(&tmpbuf);
+    rv = oh_decode_entitypath( ep, &tmpbuf );
+    if ( rv != SA_OK ) {
+        proc( "Invalid Entity" );
+        return rv;
+    }
+    strcpy( buf, "Management access for " );
+    strncat( buf, (const char *)tmpbuf.Data, tmpbuf.DataLength );
+    strcat( buf, ":\n" );
+    proc( buf );
+
+    rv = SA_OK;    
+    i = SAHPI_FIRST_ENTRY;
+    first = SAHPI_TRUE;
+    found = SAHPI_FALSE;
+    while ( rv == SA_OK ) {
+        buf[0] = '\0';
+        rv = saHpiGetIdByEntityPath( domain->sessionId, *ep, type, &i, &rid, &instr, &update_cnt );
+        if ( rv != SA_OK ) {
+            break;
+        }
+        if ( type == SAHPI_NO_RECORD ) {
+            snprintf( buf, SHOW_BUF_SZ, "  Resource %u\n", rid );
+        } else {
+            const char * type_str;
+            switch ( type ) {
+                case SAHPI_CTRL_RDR:
+                    type_str = "Control";
+                    type = SAHPI_CTRL_RDR;
+                    break;
+                case SAHPI_SENSOR_RDR:
+                    type_str = "Sensor";
+                    type = SAHPI_SENSOR_RDR;
+                    break;
+                case SAHPI_INVENTORY_RDR:
+                    type_str = "IDR";
+                    type = SAHPI_INVENTORY_RDR;
+                    break;
+                case SAHPI_WATCHDOG_RDR:
+                    type_str = "Watchdog";
+                    type = SAHPI_WATCHDOG_RDR;
+                    break;
+                case SAHPI_ANNUNCIATOR_RDR:
+                    type_str = "Annunciator";
+                    type = SAHPI_ANNUNCIATOR_RDR;
+                    break;
+                case SAHPI_DIMI_RDR:
+                    type_str = "DIMI";
+                    type = SAHPI_DIMI_RDR;
+                    break;
+                case SAHPI_FUMI_RDR:
+                    type_str = "FUMI";
+                    type = SAHPI_FUMI_RDR;
+                    break;
+                default:
+                    type_str = "Unknown Instrument";
+            }
+            snprintf( buf, SHOW_BUF_SZ, "  Resource %u, %s %u\n", rid, type_str, instr );
+        }
+        proc( buf );
+        found = SAHPI_TRUE;
+        first = SAHPI_FALSE;
+        if ( i == SAHPI_LAST_ENTRY ) {
+            break;
+        }
+    }
+    if ( found == SAHPI_FALSE ) {
+        if ( type == SAHPI_NO_RECORD ) {
+            proc( "  No resources found\n" );
+        } else {
+            proc( "  No instruments found\n" );
+        }
+    }
+    if ( ( rv == SA_ERR_HPI_NOT_PRESENT ) && ( first != SAHPI_FALSE ) ) {
+        return SA_OK;
+    } else if ( rv != SA_OK ) {
+        snprintf( buf, SHOW_BUF_SZ, "ERROR!!! saHpiGetIdByEntityPath: %s\n",
+                  oh_lookup_error( rv ) );
+        proc( buf );
+    }
+    return rv;
+}
+
+SaErrorT show_entity_tree( Domain_t *domain, const SaHpiEntityPathT * parent,
+                           unsigned int level, hpi_ui_print_cb_t proc )
+{
+    SaErrorT rv;
+    char buf[SHOW_BUF_SZ];
+    oh_big_textbuffer tmpbuf;
+
+    SaHpiEntityPathT child;
+    SaHpiUint32T i, j;
+    SaHpiBoolT first;
+    SaHpiUint32T update_cnt;
+
+    rv = SA_OK;    
+    i = SAHPI_FIRST_ENTRY;
+    first = SAHPI_TRUE;
+    while ( rv == SA_OK ) {
+        buf[0] = '\0';
+        rv = saHpiGetChildEntityPath( domain->sessionId, *parent, &i, &child, &update_cnt );
+        if ( rv != SA_OK ) {
+            break;
+        }
+        for ( j = 1; j <= level; ++j ) {
+            if ( j == level ) {
+                strcat( buf, " |-" );
+            } else {
+                strcat( buf, " | " );
+            }
+        }
+        oh_init_bigtext(&tmpbuf);
+        rv = oh_decode_entitypath( &child, &tmpbuf );
+        if ( rv == SA_OK ) {
+            strncat( buf, (const char *)tmpbuf.Data, tmpbuf.DataLength );
+            strcat( buf, "\n" );
+        } else {
+            strcat( buf, "Invalid Entity\n" );
+        }
+        proc( buf );
+        rv = show_entity_tree( domain, &child, level + 1, proc );
+
+        first = SAHPI_FALSE;
+        if ( i == SAHPI_LAST_ENTRY ) {
+            break;
+        }
+    }
+    if ( ( rv == SA_ERR_HPI_NOT_PRESENT ) && ( first != SAHPI_FALSE ) ) {
+        return SA_OK;
+    } else if ( rv != SA_OK ) {
+        snprintf( buf, SHOW_BUF_SZ, "ERROR!!! saHpiGetChildEntityPath: %s\n",
+                  oh_lookup_error( rv ) );
+        proc( buf );
+    }
+    return rv;
+}
+
 SaErrorT show_inventory(SaHpiSessionIdT sessionid, SaHpiResourceIdT resourceid,
                         SaHpiIdrIdT IdrId, SaHpiEntryIdT areaid, hpi_ui_print_cb_t proc)
 {
@@ -1063,8 +1222,8 @@ SaErrorT show_inventory(SaHpiSessionIdT sessionid, SaHpiResourceIdT resourceid,
         };
         num = info.NumAreas;
         snprintf(buf, SHOW_BUF_SZ,
-                "Inventory: %d   Update count: %d   Read only: %d   Areas: %d\n",
-                info.IdrId, info.UpdateCount, info.ReadOnly, num);
+                "Inventory: %d   Update count: %d   Read Only: %s   Areas: %d\n",
+                info.IdrId, info.UpdateCount, HPIBOOL2STR( info.ReadOnly ), num);
         if (proc(buf) != 0) return(SA_OK);
         entryid = SAHPI_FIRST_ENTRY;
         while ((entryid != SAHPI_LAST_ENTRY) && (num > 0)) {
@@ -1082,8 +1241,8 @@ SaErrorT show_inventory(SaHpiSessionIdT sessionid, SaHpiResourceIdT resourceid,
                 str = oh_lookup_idrareatype(hdr.Type);
                 if (str == NULL) str = "Unknown";
                 snprintf(buf, SHOW_BUF_SZ,
-                        "    Area: %d   Type: %s   Read Only: %d   Fields: %d\n",
-                        hdr.AreaId, str, hdr.ReadOnly, hdr.NumFields);
+                        "    Area: %d   Type: %s   Read Only: %s   Fields: %d\n",
+                        hdr.AreaId, str, HPIBOOL2STR( hdr.ReadOnly ), hdr.NumFields);
                 if (proc(buf) != 0) return(SA_OK);
                 fentryid = SAHPI_FIRST_ENTRY;
                 entryid = nextentryid;
@@ -1098,8 +1257,8 @@ SaErrorT show_inventory(SaHpiSessionIdT sessionid, SaHpiResourceIdT resourceid,
                         str = oh_lookup_idrfieldtype(field.Type);
                         if (str == NULL) str = "Unknown";
                         snprintf(buf, SHOW_BUF_SZ,
-                                "        Field: %d  Type: %s Read Only: %d (",
-                                field.FieldId, str, field.ReadOnly);
+                                "        Field: %d  Type: %s Read Only: %s (",
+                                field.FieldId, str, HPIBOOL2STR( field.ReadOnly ));
                         if (proc(buf) != 0) return(SA_OK);
                         if (print_text_buffer(NULL, &(field.Field), NULL, proc) != 0)
                                 return(SA_OK);
@@ -1123,8 +1282,7 @@ void show_inv_area_header(SaHpiIdrAreaHeaderT *Header, int del, hpi_ui_print_cb_
         if (proc(buf) != 0) return;
         snprintf(str, len, "AreaType: %s\n", oh_lookup_idrareatype(Header->Type));
         if (proc(buf) != 0) return;
-        snprintf(str, len, "ReadOnly: %s\n",
-                (Header->ReadOnly == SAHPI_TRUE) ? "TRUE" : "FALSE" );
+        snprintf(str, len, "ReadOnly: %s\n", HPIBOOL2STR( Header->ReadOnly ));
         if (proc(buf) != 0) return;
         snprintf(str, len, "NumFields: %d\n", Header->NumFields);
         proc(buf);
@@ -1143,8 +1301,7 @@ void show_inv_field(SaHpiIdrFieldT *Field, int del, hpi_ui_print_cb_t proc)
         if (proc(buf) != 0) return;
         snprintf(str, len, "Field Type: %s\n", oh_lookup_idrfieldtype(Field->Type));
         if (proc(buf) != 0) return;
-        snprintf(str, len, "ReadOnly: %s\n",
-                (Field->ReadOnly == SAHPI_TRUE) ? "TRUE" : "FALSE" );
+        snprintf(str, len, "ReadOnly: %s\n", HPIBOOL2STR( Field->ReadOnly ));
         if (proc(buf) != 0) return;
         *str = 0;
         proc(buf);
