@@ -17,8 +17,14 @@
 #define __OH_PLUGIN_H
 
 #include <glib.h>
+#include <gmodule.h>
+
 #include <oh_handler.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /*
  * Plugins are kept in a list within the oh_plugins struct
  */
@@ -29,7 +35,7 @@ struct oh_plugins {
 struct oh_plugin {
         char *name; /* Name of plugin preceded by 'lib' (e.g. "libdummy"). */
         /* handle returned by lt_dlopenext or 0 for static plugins */
-        void *dl_handle;
+        GModule *dl_handle;
         struct oh_abi_v2 *abi; /* pointer to associated plugin interface */
         int handler_count; /* How many handlers use this plugin */
 
@@ -95,4 +101,8 @@ SaErrorT oh_discovery(void);
 /* Bind abi functions into plugin */
 int oh_load_plugin_functions(struct oh_plugin *plugin, struct oh_abi_v2 **abi);
 
+#ifdef __cplusplus
+} /* extern "C" */
+#endif
+
 #endif /*__OH_PLUGIN_H*/
