@@ -12,6 +12,7 @@
  *     Thomas Kanngieser <thomas.kanngieser@fci.com>
  */
 
+#include <glib.h>
 #include "marshal.h"
 #include "marshal_hpi_types.h"
 #include <string.h>
@@ -26,7 +27,7 @@ typedef struct
   tUint8 m_pad3;
 } cTest;
 
-cMarshalType TestVarArrayType = dVarArray( SaHpiDimiTestVariableParamsType, 1 );
+cMarshalType TestVarArrayType = dVarArray( 1, SaHpiDimiTestVariableParamsT, SaHpiDimiTestVariableParamsType );
 cMarshalType StructElements[] =
 {
   dStructElement( cTest, m_pad1 , Marshal_Uint8Type ),
@@ -36,7 +37,7 @@ cMarshalType StructElements[] =
   dStructElement( cTest, m_pad3 , Marshal_Uint8Type ),
   dStructElementEnd()
 };
-cMarshalType TestType = dStruct( cTest, StructElements );
+cMarshalType TestType = dStruct( StructElements );
 SaHpiDimiTestVariableParamsT params_list[] = {
 	{
 		.ParamName = "Test Param",
@@ -62,7 +63,7 @@ main( int argc, char *argv[] )
   cTest          result;
 
   unsigned int s1 = Marshal( &TestType, &value, buffer );
-  unsigned int s2 = Demarshal( MarshalByteOrder(), &TestType, &result, buffer );
+  unsigned int s2 = Demarshal( G_BYTE_ORDER, &TestType, &result, buffer );
 
   if ( s1 != s2 )
        return 1;
