@@ -110,7 +110,7 @@ gpointer oa_soap_event_thread(gpointer oa_pointer)
         SaHpiBoolT is_plugin_initialized = SAHPI_FALSE;
         SaHpiBoolT is_discovery_completed = SAHPI_FALSE;
         SaHpiBoolT listen_for_events = SAHPI_TRUE;
-        char *user_name, *password, url[MAX_URL_LEN];
+        char *user_name, *password, *url = NULL;  
 
         if (oa_pointer == NULL) {
                 err("Invalid parameter");
@@ -207,9 +207,14 @@ gpointer oa_soap_event_thread(gpointer oa_pointer)
         /* Ideally, the soap_open should pass in 1st try.
          * If not, try until soap_open succeeds
          */
-        memset(url, 0, MAX_URL_LEN);
-        snprintf(url, strlen(oa->server) + strlen(PORT) + 1,
+        rv = asprintf(&url, 				
                  "%s" PORT, oa->server);
+        if(rv == -1){
+                free(url);
+                err("Failed to allocate memory for buffer to        \
+                                             hold OA credentials");
+                return (gpointer*) SA_ERR_HPI_OUT_OF_MEMORY;
+        } 		
         while (oa->event_con2 == NULL) {
         	OA_SOAP_CHEK_SHUTDOWN_REQ(oa_handler, NULL, NULL, NULL);
                 oa->event_con2 = soap_open(url, user_name, password,
@@ -262,10 +267,16 @@ gpointer oa_soap_event_thread(gpointer oa_pointer)
                                         soap_close(oa->event_con2);
                                         oa->event_con2 = NULL;
                                 }
-                                memset(url, 0, MAX_URL_LEN);
-                                snprintf(url, strlen(oa->server) +
-                                         strlen(PORT) + 1,
-                                        "%s" PORT, oa->server);
+                                rv = asprintf(&url, "%s" PORT, oa->server);  	
+                                if(rv == -1){
+                                        free(url);
+                                        err("Failed to allocate memory for	\
+                                                  buffer to hold OA credentials");
+
+                                        return (gpointer*) SA_ERR_HPI_OUT_OF_MEMORY;
+                                }
+
+
 
                                 /* Ideally, the soap_open should pass in
                                  * 1st try. If not, try until soap_open succeeds
@@ -283,14 +294,15 @@ gpointer oa_soap_event_thread(gpointer oa_pointer)
                                                           sleep(60);
                                                 else
                                                           sleep(5);
-                                                err("soap_open for oa->event_con2 failed\n");
+                                                err("soap_open for \
+oa->event_con2 failed\n");
                                         }
                                 }
                         } /* end of else (non-switchover error handling) */
                 } /* end of else (SOAP call failure handling) */
 
         } /* end of 'while(listen_for_events == SAHPI_TRUE)' loop */
-
+	free(url);
         return (gpointer *) SA_OK;
 }
 
@@ -393,7 +405,8 @@ void oa_soap_error_handling(struct oh_handler_state *oh_handler,
                          */
                 	OA_SOAP_CHEK_SHUTDOWN_REQ(oa_handler, oa_handler->mutex,
 						  oa->mutex, NULL);
-                        rv = oa_soap_re_discover_resources(oh_handler, oa, is_switchover);
+                        rv = oa_soap_re_discover_resources(oh_handler, oa,
+                                                           is_switchover);
                         g_mutex_unlock(oa->mutex);
                         g_mutex_unlock(oa_handler->mutex);
                         if (rv != SA_OK) {
@@ -549,13 +562,15 @@ void process_oa_out_of_access(struct oh_handler_state *oh_handler,
                         if (rv == SA_OK) {
                                 is_oa_reachable = SAHPI_TRUE;
                         } else {
-                                /* If switchover is in progress, then sleep longer */
-                                if (( oa_handler->oa_switching == SAHPI_TRUE ) ||
-                                    ( oa->oa_status == OA_ABSENT )) 
+                                /* If switchover is in progress, then sleep  */
+                                /* longer                                    */
+                                if ((oa_handler->oa_switching == SAHPI_TRUE) ||
+                                    (oa->oa_status == OA_ABSENT)) 
                                         sleep(30);
                                 else
                                         sleep(2);
-                                dbg("check_oa_status failed, oa_status is %d\n",oa->oa_status);
+                                dbg("check_oa_status failed, oa_status is %d\n",
+                                    oa->oa_status);
                                 /* OA is not accessible. Restart the timer */
                                 g_timer_start(timer);
                                 /* Double the timeout value until it reaches
@@ -756,7 +771,9 @@ void process_oa_events(struct oh_handler_state *oh_handler,
                                 break;
 
                         case EVENT_INTERCONNECT_INFO:
-                                dbg("EVENT_INTERCONNECT_INFO -- Not processed");
+                                dbg("EVENT_INTERCONNECT_INFO");
+                                rv = process_interconnect_info_event(
+                                        oh_handler, oa->event_con2, &event);
                                 break;
                         case EVENT_INTERCONNECT_HEALTH_LED:
                                 dbg("EVENT_INTERCONNECT_HEALTH_LED "
@@ -926,7 +943,8 @@ void process_oa_events(struct oh_handler_state *oh_handler,
                                     "-- Not processed");
                                 break;
                         case EVENT_MEDIA_INSERTED:
-                                /* EVENT_OA_INFO that arrives later is processed */
+                                /* EVENT_OA_INFO that arrives later is  */
+                                /* processed                            */
                                 dbg("EVENT_MEDIA_INSERTED -- Not processed");
                                 break;
                         case EVENT_MEDIA_REMOVED:
@@ -1118,6 +1136,9 @@ void process_oa_events(struct oh_handler_state *oh_handler,
                         case EVENT_ENC_WIZARD_STATUS:
                                 dbg("EVENT_ENC_WIZARD_STATUS -- Not processed");
                                 break;
+                        case EVENT_ENC_GRP_CAP:
+                                dbg("EVENT_ENC_GRP_CAP -- Not processed");
+                                break;
                         case EVENT_SSHKEYS_INSTALLED:
                                 dbg("EVENT_SSHKEYS_INSTALLED -- Not processed");
                                 break;
