@@ -32,8 +32,8 @@
  *      Raghavendra P.G. <raghavendra.pg@hp.com>
  */
 
-#ifndef _OA_SOAP_POWER_SUPPLY_EVENT_H
-#define _OA_SOAP_POWER_SUPPLY_EVENT_H
+#ifndef _OA_SOAP_PS_EVENT_H
+#define _OA_SOAP_PS_EVENT_H
 
 /* Include files */
 #include "oa_soap_re_discover.h"
@@ -51,4 +51,8 @@ void oa_soap_proc_ps_subsys_info(struct oh_handler_state *oh_handler,
 void oa_soap_proc_ps_status(struct oh_handler_state *oh_handler,
 			    struct powerSupplyStatus *status);
 
+void oa_soap_push_power_events(struct oh_handler_state *oh_handler,
+                               struct powerSubsystemInfo *info,
+                               SaHpiResourceIdT resource_id);
+
 #endif
