@@ -16,6 +16,7 @@
  */
 
 #include <glib.h>
+#include <stddef.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -59,28 +60,31 @@ SaErrorT oh_encode_entitypath(const gchar *epstr, SaHpiEntityPathT *ep)
 	SaHpiTextBufferT tmpbuffer;
 	SaHpiEntityTypeT eptype;
 
-	if (!epstr || epstr[0] == '\0' || !ep) {
-		err("Invalid parameter.");
+	if (!epstr || !ep) {
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 
 	/* Check for runaway string */
 	if (strlen(epstr) >  OH_MAX_TEXT_BUFFER_LENGTH) {
-		err("Invalid parameter.");
 		return(SA_ERR_HPI_INVALID_DATA);
 	}
 
         /* Split out {xxx,yyy} definition pairs */
        	gstr = g_strstrip(g_strdup(epstr));
-	if (gstr == NULL || gstr[0] == '\0') {
-		err("Stripped entity path string is NULL"); 
+	if (gstr == NULL) {
+		CRIT("Stripped entity path string is NULL"); 
 		err = SA_ERR_HPI_INVALID_DATA;
 		goto CLEANUP;
 	}
+	if (gstr[0] == '\0') {
+	        oh_init_ep(ep);
+		err = SA_OK;
+		goto CLEANUP;
+	}
 
 	epathdefs = g_strsplit(gstr, EPATHSTRING_END_DELIMITER, -1);
 	if (epathdefs == NULL) {
-		err("Cannot split entity path string.");
+		CRIT("Cannot split entity path string.");
 		err = SA_ERR_HPI_INTERNAL_ERROR;
 		goto CLEANUP;
         }
@@ -92,7 +96,7 @@ SaErrorT oh_encode_entitypath(const gchar *epstr, SaHpiEntityPathT *ep)
 		/* Check format - for starting delimiter and a comma */
 		if ((epathdefs[i][0] != EPATHSTRING_START_DELIMITER_CHAR) || 
 		    (strpbrk(epathdefs[i], EPATHSTRING_VALUE_DELIMITER) == NULL)) {
-			err("Invalid entity path format.");
+			CRIT("Invalid entity path format.");
 			err = SA_ERR_HPI_INVALID_DATA;
 			goto CLEANUP;
 		}
@@ -112,7 +116,7 @@ SaErrorT oh_encode_entitypath(const gchar *epstr, SaHpiEntityPathT *ep)
 			err = SA_OK;
                         int num = strtol(g_strstrip(epathvalues[0]), &endptr, 0);
                         if (num <= 0 || endptr[0] != '\0') {
-                                err("Invalid entity type string");
+                                CRIT("Invalid entity type string");
                                 err = SA_ERR_HPI_INVALID_DATA;
                                 goto CLEANUP;
                         }
@@ -122,16 +126,15 @@ SaErrorT oh_encode_entitypath(const gchar *epstr, SaHpiEntityPathT *ep)
 		/* Find entity location */
 		location = strtol(g_strstrip(epathvalues[1]), &endptr, 10);
 		if (endptr[0] != '\0') {
-			err("Invalid location character");
+			CRIT("Invalid location character");
 			err = SA_ERR_HPI_INVALID_DATA;
 			goto CLEANUP;
                 }
 
 		/* Save entity path definitions; reverse order */
 		if (num_entities < SAHPI_MAX_ENTITY_PATH) {
-			entityptr = (SaHpiEntityT *)g_malloc0(sizeof(*entityptr));
+			entityptr = g_new0(SaHpiEntityT, 1);
 			if (entityptr == NULL) {
-				err("No memory.");
 				err = SA_ERR_HPI_OUT_OF_SPACE;
 				goto CLEANUP;
 			}
@@ -161,7 +164,7 @@ SaErrorT oh_encode_entitypath(const gchar *epstr, SaHpiEntityPathT *ep)
 	}
 
 	if (num_entities > SAHPI_MAX_ENTITY_PATH) {
-		err("Too many entity defs");
+		CRIT("Too many entity defs");
 		err = SA_ERR_HPI_INVALID_DATA;
 	}
 
@@ -215,16 +218,14 @@ SaErrorT oh_decode_entitypath(const SaHpiEntityPathT *ep,
 	SaErrorT  err = SA_OK;
 
 	if (!bigbuf || !ep) {
-		err("Invalid parameter");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 
 	err = oh_init_bigtext(&tmpbuf);
 	if (err) return(err);
 
-	locstr = (gchar *)g_malloc0(OH_MAX_LOCATION_DIGITS + 1);
+	locstr = g_new0(gchar, OH_MAX_LOCATION_DIGITS + 1);
 	if (locstr == NULL) {
-		err("No memory.");
 		err = SA_ERR_HPI_OUT_OF_SPACE;
 		goto CLEANUP;
 	}
@@ -248,7 +249,7 @@ SaErrorT oh_decode_entitypath(const SaHpiEntityPathT *ep,
 		     num_digits++);
 		
 		if (num_digits > OH_MAX_LOCATION_DIGITS) {
-                        err("Location value too big");
+                        CRIT("Location value too big");
                         err = SA_ERR_HPI_INVALID_DATA;
 			goto CLEANUP;
 		}
@@ -301,7 +302,6 @@ SaErrorT oh_init_ep(SaHpiEntityPathT *ep)
 	 int i;
 
          if (!ep) {
-		 err("Invalid parameter.");
 		 return(SA_ERR_HPI_INVALID_PARAMS);
 	 }
          
@@ -313,6 +313,85 @@ SaErrorT oh_init_ep(SaHpiEntityPathT *ep)
 	 return(SA_OK);
  }
 
+/**
+ * oh_ep_len:
+ * @ep: Pointer to SaHpiEntityPathT structure to get length.
+ *
+ * Returns entity path length - number of entries before {ROOT,0} element.
+ * Returns 0 in case of NULL ep pointer.
+ **/
+SaHpiUint8T oh_ep_len( const SaHpiEntityPathT * ep )
+{
+    if ( !ep ) {
+        return 0;
+    }
+
+    size_t i;
+    for ( i = 0; i < SAHPI_MAX_ENTITY_PATH; ++i ) {
+        if ( ep->Entry[i].EntityType == SAHPI_ENT_ROOT ) {
+            break;
+        }
+    }
+
+    return i;
+}
+
+/**
+ * oh_get_child_ep:
+ * @ep: Pointer to entity path.
+ * @parent: Pointer to parent entity path.
+ * @child: Pointer to location that will be filled with child entity path
+ *
+ * Checks if the given entity path(@ep) consists of of the parent entity path
+ * and some child entity path.
+ * If it is so then fills child entity path.
+ *
+ * Returns:
+ * SA_OK - @ep consists of the @parent and some child.
+ * SA_ERR_HPI_INVALID_PARAMS - one of @ep, @parent, @child is NULL.
+ * SA_ERR_HPI_NOT_PRESENT - @ep doesn't consist of the @parent and some child.
+ **/
+SaErrorT oh_get_child_ep( const SaHpiEntityPathT * ep,
+                          const SaHpiEntityPathT * parent,
+                          SaHpiEntityPathT * child )
+{
+    if ( ( !ep ) || ( !parent ) || ( !child ) ) {
+        return SA_ERR_HPI_INVALID_PARAMS;
+    }
+
+    oh_init_ep( child );
+
+    size_t l_ep     = oh_ep_len( ep );
+    size_t l_parent = oh_ep_len( parent );
+
+    if ( l_ep < l_parent ) {
+        return SA_ERR_HPI_NOT_PRESENT;
+    } else if ( l_ep == l_parent ) {
+        return SA_OK;
+    }
+
+    size_t l_child = l_ep - l_parent;
+
+    size_t i;
+
+    for ( i = 0; i < l_parent; ++i ) {
+        const SaHpiEntityT * x = &ep->Entry[i + l_child];
+        const SaHpiEntityT * y = &parent->Entry[i];
+        if ( x->EntityType != y->EntityType ) {
+            return SA_ERR_HPI_NOT_PRESENT;
+        }
+        if ( x->EntityLocation != y->EntityLocation ) {
+            return SA_ERR_HPI_NOT_PRESENT;
+        }
+    }
+
+    for ( i = 0; i < l_child; ++i ) {
+        child->Entry[i] = ep->Entry[i];
+    }
+
+    return SA_OK;
+}
+
 /**
  * oh_concat_ep:
  * @dest: Pointer to entity path. Gets appended with @append.
@@ -331,7 +410,6 @@ SaErrorT oh_concat_ep(SaHpiEntityPathT *dest, const SaHpiEntityPathT *append)
         int i, j;
 
         if (!dest) {
-		err("Invalid parameter.");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 
@@ -402,12 +480,10 @@ SaErrorT oh_set_ep_location(SaHpiEntityPathT *ep, SaHpiEntityTypeT et, SaHpiEnti
         int i;
 
 	if (!ep) {
-		err("Invalid parameter.");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 
 	if (!oh_valid_ep(ep)) {
-		err("Invalid entity path");
 		return(SA_ERR_HPI_INVALID_DATA);
 	}
 
@@ -442,7 +518,6 @@ SaHpiBoolT oh_cmp_ep(const SaHpiEntityPathT *ep1, const SaHpiEntityPathT *ep2)
         unsigned int i, j;
         
         if (!ep1 || !ep2) {
-                err("Invalid parameter.");
                 return(SAHPI_FALSE);
         }
 
@@ -465,7 +540,7 @@ SaHpiBoolT oh_cmp_ep(const SaHpiEntityPathT *ep1, const SaHpiEntityPathT *ep2)
         for (i=0; i<j; i++) {
                 if (ep1->Entry[i].EntityType != ep2->Entry[i].EntityType ||
                     ep1->Entry[i].EntityLocation != ep2->Entry[i].EntityLocation) {
-                        /* dbg("Entity element %d: EP1 {%d,%d} != EP2 {%d,%d}", i, 
+                        /* DBG("Entity element %d: EP1 {%d,%d} != EP2 {%d,%d}", i, 
                             ep1->Entry[i].EntityType,
                             ep1->Entry[i].EntityLocation,
                             ep2->Entry[i].EntityType,
@@ -494,7 +569,6 @@ SaErrorT oh_fprint_ep(FILE *stream, const SaHpiEntityPathT *ep, int offsets)
         SaErrorT err;
 	
         if (!ep) {
-		err("Invalid parameter.");
 		return(SA_ERR_HPI_INVALID_PARAMS);
         }
 
@@ -586,27 +660,26 @@ gchar * oh_derive_string(SaHpiEntityPathT *ep,
         guint total_num_digits, i, work_location_num, num_digits;
 
 	if (!ep || !str) {
-		err("NULL parameter.");
 		return(NULL);
 	}
 
 	if (offset < 0) {
-		err("Invalid location offset.");
+		CRIT("Invalid location offset.");
 		return(NULL);
 	}
 
 	if (!(base == 10 || base == 16)) {
-		err("Invalid base.");
+		CRIT("Invalid base.");
 		return(NULL);
 	}
 
         for (num_epe = 0;
              ep->Entry[num_epe].EntityType != SAHPI_ENT_ROOT && num_epe < SAHPI_MAX_ENTITY_PATH;
              num_epe++);
-        /* dbg("Number of elements in entity path: %d", num_epe); */
+        /* DBG("Number of elements in entity path: %d", num_epe); */
 
         if (num_epe == 0) {
-                err("Entity Path is null.");
+                CRIT("Entity Path is null.");
                 return(NULL);
         }
         if ((str_strlen = strlen(str)) == 0) return(NULL); /* Str is zero length */
@@ -615,16 +688,16 @@ gchar * oh_derive_string(SaHpiEntityPathT *ep,
         for (num_blanks=0, i=0; i<str_strlen; i++) {
                 if (str[i] == OH_DERIVE_BLANK_CHAR) num_blanks++;
         }
-        /* dbg("Number of blanks in str: %d, %s", num_blanks, str); */
+        /* DBG("Number of blanks in str: %d, %s", num_blanks, str); */
         if (num_blanks > num_epe) {
-                err("Number of replacements=%d > entity path elements=%d", num_blanks, num_epe);
+                CRIT("Number of replacements=%d > entity path elements=%d", num_blanks, num_epe);
                 return(NULL);
         }
 
         fragments = g_strsplit(str, OH_DERIVE_BLANK_STR, - 1);
-        if (!fragments) { err("Cannot split string"); goto CLEANUP; }
-        str_nodes = g_malloc0((num_blanks + 1) * sizeof(gchar **));
-        if (!str_nodes) { err("Out of memory."); goto CLEANUP; }
+        if (!fragments) { CRIT("Cannot split string"); goto CLEANUP; }
+        str_nodes = g_new0(gchar *, num_blanks + 1);
+        if (!str_nodes) { CRIT("Out of memory."); goto CLEANUP; }
         total_num_digits = 0;
         for (i=0; i<num_blanks; i++) {
                 work_location_num = ep->Entry[num_blanks-1-i].EntityLocation;
@@ -632,8 +705,8 @@ gchar * oh_derive_string(SaHpiEntityPathT *ep,
 
                 for (num_digits = 1;
                      (work_location_num = work_location_num/base) > 0; num_digits++);
-                str_nodes[i] = g_malloc0((num_digits+1) * sizeof(gchar));
-                if (!str_nodes[i]) {err("Out of memory."); goto CLEANUP;}
+                str_nodes[i] = g_new0(gchar, num_digits+1);
+                if (!str_nodes[i]) {CRIT("Out of memory."); goto CLEANUP;}
 		if (base == 10) {
 			snprintf(str_nodes[i], (num_digits + 1) * sizeof(gchar), "%d", 
 				 ep->Entry[num_blanks - 1 - i].EntityLocation + offset);
@@ -643,22 +716,22 @@ gchar * oh_derive_string(SaHpiEntityPathT *ep,
 				 ep->Entry[num_blanks - 1 - i].EntityLocation + offset);
 		}
 
-                /* dbg("Location number: %s", str_nodes[i]); */
+                /* DBG("Location number: %s", str_nodes[i]); */
                 total_num_digits = total_num_digits + num_digits;
         }
 
-        new_str = g_malloc0((str_strlen-num_blanks + total_num_digits + 1) * sizeof(gchar));
-        if (!new_str) { err("Out of memory."); goto CLEANUP; }
+        new_str = g_new0(gchar, str_strlen-num_blanks + total_num_digits + 1);
+        if (!new_str) { CRIT("Out of memory."); goto CLEANUP; }
         str_walker = new_str;
         for (i=0; fragments[i]; i++) {
                 str_walker = strcpy(str_walker, fragments[i]);
                 str_walker = str_walker + strlen(fragments[i]);
                 if (str_nodes[i]) {
                         str_walker = strcpy(str_walker, str_nodes[i]);
-                        /* dbg("Location number: %s", str_nodes[i]); */
+                        /* DBG("Location number: %s", str_nodes[i]); */
                         str_walker = str_walker + strlen(str_nodes[i]);
                 }
-                /* dbg("New str: %s", new_str); */
+                /* DBG("New str: %s", new_str); */
         }
 
 CLEANUP:
@@ -699,7 +772,6 @@ SaErrorT oh_compile_entitypath_pattern(const char *epp_str,
         oh_entitypath_pattern pattern;
 
         if (!epp_str || !epp) {
-                err("Got null parameters.");
                 return SA_ERR_HPI_INVALID_PARAMS;
         }
         memset(&pattern, 0, sizeof(oh_entitypath_pattern));
